@@ -21,24 +21,6 @@
 
 #Rscript path_to/maximumIsometricForce.R path_tmp
 
-prepareGraph <- function(os, pngFile, width, height)
-{
-        if(os == "Windows"){
-                library("Cairo")
-                Cairo(width, height, file = pngFile, type="png", bg="white")
-        }
-        else
-                png(pngFile, width=width, height=height)
-        #pdf(file = "/tmp/maxIsomForce.pdf", width=width, height=height)
-}
-
-#Ends the graph
-
-endGraph <- function()
-{
-        dev.off()
-}
-
 #Read each non commented line of the Roptions file
 
 assignOptions <- function(options)
@@ -64,7 +46,8 @@ assignOptions <- function(options)
                 drawRfdOptions          = drawRfdOptions,
                 drawImpulseOptions      = options[16],
 		testLength 		= as.numeric(options[17]),
-		title 	 		= options[18]
+		title 	 		= options[18],
+                scriptsPath 		= options[19]
         ))
 }
 
@@ -83,6 +66,8 @@ options <- scan(optionsFile, comment.char="#", what=character(), sep="\n")
 op <- assignOptions(options)
 print(op)
 
+source(paste(op$scriptsPath, "/scripts-util.R", sep=""))
+
 
 #Fits the data to the model f = fmax*(1 - exp(-K*t))
 #Important! It fits the data with the axes moved to initf and startTime. The real maximum force is fmax + initf
@@ -112,7 +97,7 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
         
         #Finding the decrease of the foce to detect the end of the maximum voluntary force
         trimmingSamples = getTrimmingSamples(originalTest, rfd, averageLength = averageLength, percentChange = percentChange,
-					     testLength = op$testLength)
+					     testLength = op$testLength, startDetectingMethod = "SD")
         startSample = trimmingSamples$startSample
         startTime = originalTest$time[startSample]
         
@@ -329,9 +314,9 @@ drawDynamicsFromLoadCell <- function(
         arrows(x0 = 0, y0 = dynamics$f0.raw,
                x1 = dynamics$tau.fitted, y1 = dynamics$f0.raw)
         text(x = (dynamics$tau.fitted / 2), y = dynamics$f0.raw,
-              labels = paste("τ =", round(dynamics$tau.fitted, digits = 2), "s"), pos = 3, cex = 1.5, col = "blue")
+              labels = paste(round(dynamics$tau.fitted, digits = 2), "s"), pos = 3, cex = 1.5, col = "blue")
         # text(x = (dynamics$tau.fitted / 2), y = -20,
-        #      labels = paste("τ =", round(dynamics$tau.fitted, digits = 2), "s"), pos = 3, cex = 1.5, xpd = TRUE)
+        #      labels = paste(round(dynamics$tau.fitted, digits = 2), "s"), pos = 3, cex = 1.5, xpd = TRUE)
         
         arrows(x0 = 0, y0 = 0,
                x1 = 0, y1 = dynamics$fmax.fitted*0.6321206)
@@ -378,8 +363,8 @@ drawDynamicsFromLoadCell <- function(
         
         legendText = c(
 		       paste("Fmax =", round(dynamics$fmax.fitted, digits = 2), "N"),
-		       paste("K = ", round(dynamics$k.fitted, digits = 2),"s⁻¹"),
-		       paste("τ = ", round(dynamics$tau.fitted, digits = 2),"s")
+		       paste("K = ", round(dynamics$k.fitted, digits = 2),"s^-1"),
+		       paste("tau = ", round(dynamics$tau.fitted, digits = 2),"s")
 		       )
         legendColor = c("blue", "blue", "blue")
         
@@ -435,10 +420,10 @@ drawDynamicsFromLoadCell <- function(
                                 } else if(RFDoptions$rfdFunction == "RAW")
                                 {
                                         #Slope of the line of the sampled point.
-                                        RFD = getForceAtTime(dynamics$time, dynamics$rfd, time1)
+                                        RFD = interpolateXAtY(dynamics$rfd, dynamics$time, time1)
                                         
                                         #Y coordinate of a point of the line
-                                        force1 = getForceAtTime(dynamics$time, dynamics$f.raw, RFDoptions$start)
+                                        force1 = interpolateXAtY(dynamics$f.raw, dynamics$time, RFDoptions$start)
                                         
                                         legendText = c(legendText, paste("RFD", RFDoptions$start*1000, " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "black")
@@ -466,8 +451,8 @@ drawDynamicsFromLoadCell <- function(
                                         
                                 } else if(RFDoptions$rfdFunction == "RAW")
                                 {
-                                        force1 = getForceAtTime(dynamics$time, dynamics$f.raw, RFDoptions$start)
-                                        force2 = getForceAtTime(dynamics$time, dynamics$f.raw, RFDoptions$end)
+                                        force1 = interpolateXAtY(dynamics$f.raw, dynamics$time, RFDoptions$start)
+                                        force2 = interpolateXAtY(dynamics$f.raw, dynamics$time, RFDoptions$end)
                                         
                                         #Slope of the line
                                         RFD = (force2 - force1) / (time2 - time1)
@@ -496,13 +481,13 @@ drawDynamicsFromLoadCell <- function(
                                         
                                 } else if(RFDoptions$rfdFunction == "RAW")
                                 {
-                                        time1 = getTimeAtForce(dynamics$time, dynamics$f.raw, dynamics$fmax.raw * percent / 100)
+                                        time1 = interpolateXAtY(dynamics$time, dynamics$f.raw, dynamics$fmax.raw * percent / 100)
                                         
                                         #Slope of the line
-                                        RFD = getForceAtTime(dynamics$time, dynamics$rfd, time1)
+                                        RFD = interpolateXAtY(dynamics$rfd, dynamics$time, time1)
                                         
                                         #Y coordinate of a point of the line
-                                        force1 = getForceAtTime(dynamics$time, dynamics$f.raw, time1)
+                                        force1 = interpolateXAtY(dynamics$f.raw, dynamics$time, time1)
                                         
                                         legendText = c(legendText, paste("RFD", percent, "%", "Fmax", " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "black")
@@ -618,26 +603,29 @@ getTrimmingSamples <- function(test, rfd, movingAverageForce, averageLength = 0.
 {
         movingAverageForce = getMovingAverageForce(test, averageLength = 0.1)
         maxRFD = max(rfd[2:(length(rfd) - 1)])
+        maxRFDSample = which.max(rfd[2:(length(rfd) - 1)])
         
         #Detecting when the force is greater of the mean + 3*SD of 20 samples
+        #If in various sample the force are greater, the last one before the maxRFD are taken
         #See Rate of force development: physiological and methodological considerations. Nicola A. Maffiuletti1 et al.
+        
+        startSample = NULL
         if (startDetectingMethod == "SD"){
-                startSample = 21
-                while(test$force[startSample] < mean(test$force[startSample:(startSample - 20)]) + 3*sd(test$force[startSample:(startSample - 20)]))
+                for(currentSample in 21:maxRFDSample)
                 {
-                        startSample = startSample + 1
+                        if(test$force[currentSample] < mean(test$force[currentSample:(currentSample - 20)]) + 3*sd(test$force[currentSample:(currentSample - 20)]))
+                                startSample = currentSample
                 }
                 
-                while(test$force[startSample] - test$force[startSample -1] >= 0){ #Detecting the sample to decrease
+                while(test$force[startSample] - test$force[startSample -1] >= 0){ #Going back to the last sample that decreased
                         startSample = startSample - 1
                 }
-                
-        #Detecting when accurs a greate growth of the force
+        #Detecting when accurs a great growth of the force (great RFD)
         } else if (startDetectingMethod == "RFD"){
-                startSample = 2
-                while(rfd[startSample] <= maxRFD*0.2)
+                for(currentSample in 2:maxRFDSample)
                 {
-                        startSample = startSample + 1
+                        if(rfd[currentSample] <= maxRFD*0.2)
+                                startSample = currentSample
                 }
         }
         
@@ -729,51 +717,6 @@ readImpulseOptions <- function(optionsStr)
         } 
 }
 
-#Function to get the interpolated force at a given time in seconds)
-getForceAtTime <- function(time, force, desiredTime){
-        #find the closest sample
-        closestSample = which.min(abs(time - desiredTime))
-        
-        if(time[closestSample] - desiredTime >= 0){
-                previousSample = closestSample - 1
-                nextSample = closestSample
-        } else if(time[closestSample] - desiredTime < 0){
-                previousSample = closestSample
-                nextSample = closestSample + 1
-        }
-        print("Samples:")
-        print(paste(previousSample, nextSample))
-        print("Times:")
-        print(paste(time[previousSample], time[nextSample]))
-        print("Forces:")
-        print(paste(force[previousSample], force[nextSample]))
-        
-        #Interpolation between two samples
-        desiredForce = force[previousSample] + ((force[nextSample] - force[previousSample]) / (time[nextSample] - time[previousSample]))*(desiredTime - time[previousSample])
-        print("DesiredForce:")
-        print(desiredForce)
-        return(desiredForce)
-}
-
-#Function to get the interpolated time at a given force in N
-getTimeAtForce <- function(time, force, desiredForce){
-        #find the closest sample
-        nextSample = 1
-        while (force[nextSample] < desiredForce){
-                nextSample = nextSample +1
-        }
-        
-        previousSample = nextSample - 1
-        
-        if(force[nextSample] == desiredForce){
-                desiredTime = time[nextSample]
-        } else {
-                desiredTime = time[previousSample] + (desiredForce  - force[previousSample]) * (time[nextSample] - time[previousSample]) / (force[nextSample] - force[previousSample])
-        }
-        return(desiredTime)
-}
-
-
 prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
 dynamics = getDynamicsFromLoadCellFile(dataFile, op$averageLength, op$percentChange)
 drawDynamicsFromLoadCell(dynamics, op$vlineT0, op$vline50fmax.raw, op$vline50fmax.fitted, op$hline50fmax.raw, op$hline50fmax.fitted,
