@@ -34,12 +34,25 @@ options <- scan(optionsFile, comment.char="#", what=character(), sep="\n")
 #options[1] is scriptsPath
 source(paste(options[1], "/sprintUtil.R", sep=""))
 
+
+assignOptions <- function(options) {
+        return(list(
+                scriptsPath	= options[1],
+                positions  	= as.numeric(unlist(strsplit(options[2], "\\;"))),
+                splitTimes 	= as.numeric(unlist(strsplit(options[3], "\\;"))),
+                mass 	= as.numeric(options[4]),
+                personHeight = as.numeric(options[5]),
+                tempC 	= as.numeric(options[6]),
+                os 		= options[7],
+                graphWidth 	= as.numeric(options[8]),
+                graphHeight	= as.numeric(options[9])
+        ))
+}
+
 #-------------- assign options -------------
 op <- assignOptions(options)
 #print(op$positions)
 
-
-
 #Returns the K and Vmax parameters of the sprint using a number of pairs (time, position)
 getSprintFromPhotocell <- function(positions, splitTimes, noise=0)
 {
@@ -155,7 +168,7 @@ drawSprintFromPhotocells <- function(sprintDynamics, splitTimes, positions, titl
                 plot(time, sprintDynamics$p.fitted, type="l", axes = FALSE, xlab="", ylab="", col="red", ylim=c(0,sprintDynamics$pmax.fitted + .1 * sprintDynamics$pmax.fitted), yaxs= "i", xaxs = "i")
                 abline(v = sprintDynamics$tpmax.fitted, col="red", lty = 2)
                 axis(side = 4, col ="red", at = seq(0, sprintDynamics$pmax.fitted, by = 200))
-                axis(3, at = sprintDynamics$tpmax.fitted, labels = sprintDynamics$tpmax.fitted)
+                axis(3, at = sprintDynamics$tpmax.fitted, labels = round(sprintDynamics$tpmax.fitted, 3))
                 #text(sprintDynamics$tpmax.fitted, sprintDynamics$pmax.fitted, paste("Pmax fitted =", round(sprintDynamics$pmax.fitted, digits = 2)),  pos = 3)
                 # mtext(side = 1, line = 5, at = splitTimes[length(splitTimes)]*0.75, cex = 1.5,
                 #       substitute(P(t) == A*e^(-K*t)*(1-e^(-K*t)) + B*(1-e^(-K*t))^3,
@@ -175,12 +188,7 @@ drawSprintFromPhotocells <- function(sprintDynamics, splitTimes, positions, titl
                            paste("pmax =", round(sprintDynamics$pmax.rel.fitted, digits = 2), "W/Kg")),
                 text.col = c("black", "black", "green", "blue", "red"))
         
-        exportData = list(Mass = sprintDynamics$Mass, Height = sprintDynamics$Height, Temperature = sprintDynamics$Temperature, Vw = sprintDynamics$Vw, Ka = sprintDynamics$Ka, K.fitted = sprintDynamics$K.fitted, Vmax.fitted = sprintDynamics$Vmax,
-                          amax.fitted = sprintDynamics$amax.fitted, fmax.fitted = sprintDynamics$fmax.fitted, fmax.rel.fitted = sprintDynamics$fmax.rel.fitted, sfv.fitted = sprintDynamics$sfv.fitted, sfv.rel.fitted = sprintDynamics$sfv.rel.fitted,
-                          pmax.fitted = sprintDynamics$pmax.fitted, pmax.rel.fitted = sprintDynamics$pmax.rel.fitted, tpmax.fitted = sprintDynamics$tpmax.fitted, F0 = sprintDynamics$F0, F0.rel = sprintDynamics$F0.rel, V0 = sprintDynamics$V0,
-                          sfv.lm = sprintDynamics$sfv.lm, sfv.rel.lm = sprintDynamics$sfv.rel.lm, pmax.lm = sprintDynamics$pmax.lm, pmax.rel.lm = sprintDynamics$pmax.rel.lm)
-        write.csv2(exportData, file = paste(tempPath, "/sprintResults.csv", sep = ""))
-        
+        exportSprintDynamics(sprintDynamics)
 }
 
 testPhotocellsCJ <- function(positions, splitTimes, mass, personHeight, tempC)
