@@ -20,7 +20,7 @@
 
 #This code uses splitTimes: accumulated time (not lap time)
 
-
+source(paste(options[1], "/scripts-util.R", sep=""))
 
 #Calculates all kinematic and dynamic variables using the sprint parameters (K and Vmax) and the conditions of the test (Mass and Height of the subject,
 #Temperature in the moment of the test and Velocity of the wind).
@@ -68,10 +68,59 @@ getDynamicsFromSprint <- function(K, Vmax, Mass, Temperature = 25, Height , Vw =
         pmax.rel.fitted = pmax.fitted / Mass
         tpmax.fitted = log(2) / K                    # Obtained from P'(t) = 0
         
-        return(list(Mass = Mass, Height = Height, Temperature = Temperature, Vw = Vw, Ka = Ka, K.fitted = K, Vmax.fitted = Vmax,
-                    amax.fitted = amax.fitted, fmax.fitted = fmax.fitted, fmax.rel.fitted = fmax.rel.fitted, sfv.fitted = sfv.fitted, sfv.rel.fitted = sfv.rel.fitted,
-                    pmax.fitted = pmax.fitted, pmax.rel.fitted = pmax.rel.fitted, tpmax.fitted = tpmax.fitted, F0 = F0, F0.rel = F0.rel, V0 = V0,
-                    sfv.lm = sfv.lm, sfv.rel.lm = sfv.rel.lm, pmax.lm = pmax.lm, pmax.rel.lm = pmax.rel.lm, v.fitted = v.fitted, a.fitted = a.fitted, f.fitted = f.fitted, p.fitted = p.fitted ))
+        return(list(Mass = Mass,
+                    Height = Height, Temperature = Temperature,
+                    Vw = Vw,
+                    Ka = Ka,
+                    t.fitted = time,
+                    K.fitted = K,
+                    Vmax.fitted = Vmax,
+                    amax.fitted = amax.fitted,
+                    fmax.fitted = fmax.fitted,
+                    fmax.rel.fitted = fmax.rel.fitted,
+                    sfv.fitted = sfv.fitted,
+                    sfv.rel.fitted = sfv.rel.fitted,
+                    pmax.fitted = pmax.fitted,
+                    pmax.rel.fitted = pmax.rel.fitted,
+                    tpmax.fitted = tpmax.fitted,
+                    F0 = F0,
+                    F0.rel = F0.rel,
+                    V0 = V0,
+                    sfv.lm = sfv.lm,
+                    sfv.rel.lm = sfv.rel.lm,
+                    pmax.lm = pmax.lm,
+                    pmax.rel.lm = pmax.rel.lm,
+                    v.fitted = v.fitted,
+                    a.fitted = a.fitted,
+                    f.fitted = f.fitted,
+                    p.fitted = p.fitted ))
+}
+
+exportSprintDynamics <- function(sprintDynamics)
+{
+        exportData = list(Mass = sprintDynamics$Mass,
+                          Height = sprintDynamics$Height,
+                          Temperature = sprintDynamics$Temperature,
+                          Vw = sprintDynamics$Vw,
+                          Ka = sprintDynamics$Ka,
+                          K.fitted = sprintDynamics$K.fitted,
+                          Vmax.fitted = sprintDynamics$Vmax,
+                          amax.fitted = sprintDynamics$amax.fitted,
+                          fmax.fitted = sprintDynamics$fmax.fitted,
+                          fmax.rel.fitted = sprintDynamics$fmax.rel.fitted,
+                          sfv.fitted = sprintDynamics$sfv.fitted,
+                          sfv.rel.fitted = sprintDynamics$sfv.rel.fitted,
+                          sfv.lm = sprintDynamics$sfv.lm,
+                          sfv.rel.lm = sprintDynamics$sfv.rel.lm,
+                          pmax.fitted = sprintDynamics$pmax.fitted,
+                          pmax.rel.fitted = sprintDynamics$pmax.rel.fitted,
+                          tpmax.fitted = sprintDynamics$tpmax.fitted,
+                          F0 = sprintDynamics$F0,
+                          F0.rel = sprintDynamics$F0.rel,
+                          V0 = sprintDynamics$V0,
+                          pmax.lm = sprintDynamics$pmax.lm,
+                          pmax.rel.lm = sprintDynamics$pmax.rel.lm)
+        write.csv2(exportData, file = paste(tempPath, "/sprintResults.csv", sep = ""))
 }
 
 #Finds the time correspondig to a given position in the formula x(t) = Vmax*(t + (1/K)*exp(-K*t)) -Vmax - 1/K
@@ -91,31 +140,3 @@ splitTime <- function(Vmax, K, position, tolerance = 0.001, initTime = 1)
 }
 
 
-prepareGraph <- function(os, pngFile, width, height)
-{
-	if(os == "Windows"){
-	        library("Cairo")
-		Cairo(width, height, file = pngFile, type="png", bg="white")
-	}
-	else
-		png(pngFile, width=width, height=height)
-}
-
-endGraph <- function()
-{
-	dev.off()
-}
-
-assignOptions <- function(options) {
-	return(list(
-		    scriptsPath	= options[1],
-		    positions  	= as.numeric(unlist(strsplit(options[2], "\\;"))),
-		    splitTimes 	= as.numeric(unlist(strsplit(options[3], "\\;"))),
-		    mass 	= as.numeric(options[4]),
-		    personHeight = as.numeric(options[5]),
-		    tempC 	= as.numeric(options[6]),
-		    os 		= options[7],
-		    graphWidth 	= as.numeric(options[8]),
-		    graphHeight	= as.numeric(options[9])
-		    ))
-}
