@@ -175,9 +175,9 @@ public class ChronoJump
 			 * We need here! to define the language from the beginning
 			 * so we use language = "" if version is prior to 1.25
 			 */
-			string currentVersion = SqlitePreferences.Select("databaseVersion", false);
-			double currentVersionDouble = Convert.ToDouble(Util.ChangeDecimalSeparator(currentVersion));
-			if(currentVersionDouble < Convert.ToDouble(Util.ChangeDecimalSeparator("1.25")))
+			string currentDBVersion = SqlitePreferences.Select("databaseVersion", false);
+			double currentDBVersionDouble = Convert.ToDouble(Util.ChangeDecimalSeparator(currentDBVersion));
+			if(currentDBVersionDouble < Convert.ToDouble(Util.ChangeDecimalSeparator("1.25")))
 				language = "";
 			else
 				language = SqlitePreferences.Select("language", false);
@@ -185,6 +185,10 @@ public class ChronoJump
 			Sqlite.DisConnect();
 	
 			if(language != "") {
+				//convert pt-BR to pt_BR
+				if(language.Contains("-"))
+					language = language.Replace("-", "_");
+
 				Environment.SetEnvironmentVariable ("LANGUAGE", language); //works
 #if OSTYPE_WINDOWS
 				g_setenv ("LANGUAGE", language, true);
@@ -417,7 +421,6 @@ public class ChronoJump
 			LogB.Error(js.ResultMessage);
 			*/
 
-		
 		allSQLCallsDoneOnSqliteThingsThread = false;
 			
 		//wait until pinging ends (or it's cancelled)
@@ -426,6 +429,8 @@ public class ChronoJump
 
 		Sqlite.Open();
 
+//TODO: fix this to the new code
+
 		string versionAvailableKnown = SqlitePreferences.Select("versionAvailable", true);
 		if( versionAvailable != Constants.ServerOffline && new Version(versionAvailable) > new Version(progVersion) ) {
 			//check if available version is higher than known available version
@@ -496,8 +501,7 @@ public class ChronoJump
 
 	protected void readMessageToStart()
 	{
-		//don't show error message at start if Compujump
-		if(messageToShowOnBoot.Length > 0 && ! configChronojump.Compujump)
+		if(messageToShowOnBoot.Length > 0)
 		{
 			if(chronojumpHasToExit)
 			{
@@ -512,7 +516,10 @@ public class ChronoJump
 				}
 				splashWin.ShowButtonClose();
 			} else {
-				startChronojump(true); //sendLog
+				if(configChronojump.Compujump)
+					startChronojump(false); //don't sendLog
+				else
+					startChronojump(true); //sendLog
 			}
 		} else {
 			startChronojump(false);
@@ -609,7 +616,10 @@ public class ChronoJump
 	
 	protected bool PulseGTK ()
 	{
-		if( quitNowCjTwoTimes || needEndSplashWin || ! thread.IsAlive ) {
+		if( quitNowCjTwoTimes || needEndSplashWin || ! thread.IsAlive )
+		{
+			LogB.Information(string.Format("pulseGTK ending conditions: {0}, {1}, {2}",
+						quitNowCjTwoTimes, needEndSplashWin, ! thread.IsAlive));
 			LogB.ThreadEnding();
 			fakeSplashButton.Click();
 
