@@ -172,6 +172,10 @@ public class Constants
 	public const string ReactionTimeTypeTable = "reactionTimeType";
 	public const string GraphLinkTable = "graphLinkTable";
 
+	//json temp tables
+	public const string UploadEncoderDataTempTable = "uploadEncoderDataTemp";
+	public const string UploadSprintDataTempTable = "uploadSprintDataTemp";
+
 	public const string UndefinedDefault = "Undefined";
 	public const string Any = "Any";
 
@@ -244,6 +248,9 @@ public class Constants
 	public static string TakeOffName = "TakeOff"; //translate (take off?)
 	public static string TakeOffWeightName = "TakeOffWeight"; //translate (take off?)
 
+	public static string SoftwareUpdated = Catalog.GetString("Your software is updated!");
+	public static string SoftwareNeedUpdate = Catalog.GetString("Update software at ") + "www.chronojump.org";
+	public static string SoftwareNewerThanPublised = "Your software is more updated than last published version.\n\nPlease, don't Update!";
 
 	public static string GetSpreadsheetString(string CSVExportDecimalSeparator)
 	{
@@ -462,13 +469,17 @@ public class Constants
 	public static string FileNameEncoderAnalyzePowerbarsIcon = "encoder-analyze-powerbars.png";
 	public static string FileNameEncoderAnalyzeCrossIcon = "encoder-analyze-cross.png";
 	public static string FileNameEncoderAnalyze1RMIcon = "encoder-analyze-1RM.png";
-	public static string FileNameEncoderAnalyzeSideIcon = "encoder-analyze-side.png";
+	public static string FileNameEncoderAnalyzeInstantaneousIcon = "encoder-analyze-instantaneous.png";
 	public static string FileNameEncoderAnalyzeSingleIcon = "encoder-analyze-single.png";
+	public static string FileNameEncoderAnalyzeSideIcon = "encoder-analyze-side.png";
+	public static string FileNameEncoderAnalyzeSuperposeIcon = "encoder-analyze-superpose.png";
+	public static string FileNameEncoderAnalyzeAllSetIcon = "encoder-analyze-all-set.png";
 	public static string FileNameEncoderAnalyzeNmpIcon = "encoder-analyze-nmp.png";
 	
 	public static string FileNameEncoderAnalyzeEcconTogetherIcon = "encoder-analyze-eccon-together.png";
 	public static string FileNameEncoderAnalyzeEcconSeparatedIcon = "encoder-analyze-eccon-separated.png";
 	
+	public static string FileNameEncoderAnalyzePositionIcon = "encoder-analyze-position.png";
 	public static string FileNameEncoderAnalyzeSpeedIcon = "encoder-analyze-speed.png";
 	public static string FileNameEncoderAnalyzeAccelIcon = "encoder-analyze-accel.png";
 	public static string FileNameEncoderAnalyzeForceIcon = "encoder-analyze-force.png";
@@ -642,7 +653,7 @@ public class Constants
 
 	//for dialog windows
 	public enum MessageTypes {
-		WARNING, INFO, HELP
+		WARNING, INFO, HELP, INSPECT
 	}
 
 	public static string No = Catalog.GetString("No");
@@ -919,8 +930,17 @@ public class Constants
 	
 	public enum EncoderAutoSaveCurve { ALL, NONE, BEST, FROM4TOPENULTIMATE }
 
+	//BIGGEST_TC will be the default mode.
+	// - at END of each track: track ends before the biggest TC (just before the trunk arrives)
+	// - at START of each track:
+	// 	- if starting on contact:
+	// 		time starts when leaving it. Usually will be with the biggest part (trunk),
+	// 		and maybe later there's a foot, so leaving the contact on the first time is the beginning.
+	// 	- on speed start, if there are double contacts,
+	// 		- if "race starts at arriving at platform", then race will start before big tc (trunk)
+	// 		- else, race will start after big tc (trunk)
 	public enum DoubleContact {
-		NONE, FIRST, AVERAGE, LAST
+		NONE, FIRST, AVERAGE, LAST, BIGGEST_TC
 	}
 	
 	//DISPLACED means: total
