@@ -67,7 +67,7 @@ public abstract class EncoderCapture
 	 * sumInertialDisc: on inertial this has the sum of the disc, while sum has the position of the body (always <= 0 (starting position))
 	 * on inertial we need both
 	 */
-	protected double sum;	
+	protected int sum;
 	protected int sumInertialDisc;
 
 	protected int i;
@@ -101,6 +101,9 @@ public abstract class EncoderCapture
 	protected int inertialCalibratedFirstCross0Pos;
 	protected bool inertialCalibrated;
 
+	//Only for IMCalc: go and return is a period. Here we count semiperiods
+	public int IMCalcOscillations;
+
 	//capture is simulated (a signal file is readed)
 	private bool simulated = false;
 	//private int [] simulatedInts;
@@ -112,7 +115,7 @@ public abstract class EncoderCapture
 
 
 	//if cont (continuous mode), then will not end when too much time passed before start
-	public void InitGlobal (int widthG, int heightG, int time, int timeEnd,
+	public bool InitGlobal (int widthG, int heightG, int time, int timeEnd,
 			bool cont, string eccon, string port, bool capturingInertialBG, bool showOnlyBars,
 			bool simulated)
 	{
@@ -130,12 +133,19 @@ public abstract class EncoderCapture
 			rand = new Random(40);
 			SimulatedReset();
 		}
-		else if(! simulated && ! capturingInertialBG) {
+		else if(! simulated && ! capturingInertialBG)
+		{
 			LogB.Debug("runEncoderCaptureCsharp start port:", port);
 			sp = new SerialPort(port);
 			sp.BaudRate = 115200;
 			LogB.Information("sp created");
-			sp.Open();
+
+			try {
+				sp.Open();
+			} catch {
+				LogB.Information("Error: Cannot open port");
+				return false;
+			}
 			LogB.Information("sp opened");
 		}
 		
@@ -203,6 +213,8 @@ public abstract class EncoderCapture
 
 		cancel = false;
 		finish = false;
+
+		return true;
 	}
 
 	protected virtual void initSpecific()
@@ -215,7 +227,7 @@ public abstract class EncoderCapture
 	}
 
 	public bool Capture(string outputData1, EncoderRProcCapture encoderRProcCapture,
-			bool compujump, Preferences.TriggerTypes cutByTriggers, double restClustersSeconds)
+			bool compujump, Preferences.TriggerTypes cutByTriggers, double restClustersSeconds, bool playSoundsFromFile)
 	{
 		/*
 		 * removed at 1.7.0
@@ -232,6 +244,9 @@ public abstract class EncoderCapture
 		//only for cutByTriggers == Preferences.TriggerTypes.START_AT_FIRST_ON
 		bool firstTriggerHappened = false;
 
+		//playSoundsFromFile
+		DateTime lastTriggeredSound = DateTime.MinValue;
+
 		if(capturingInertialBG)
 		{
 			/*
@@ -257,6 +272,18 @@ public abstract class EncoderCapture
 			//2 check if readed data is a trigger
 			if(byteReaded == TRIGGER_ON)
 			{
+				if(playSoundsFromFile)
+				{
+					TimeSpan ts = DateTime.Now.Subtract(lastTriggeredSound);
+					if(ts.TotalMilliseconds > 50)
+					{
+						Util.NextSongInList();
+						lastTriggeredSound = DateTime.Now;
+					}
+
+					continue;
+				}
+
 				Trigger trigger = new Trigger(Trigger.Modes.ENCODER, i, true);
 				if(triggerList.IsSpurious(trigger))
 				{
@@ -308,8 +335,12 @@ public abstract class EncoderCapture
 			}
 			else if(byteReaded == TRIGGER_OFF)
 			{
-				Trigger trigger  = new Trigger(Trigger.Modes.ENCODER, i, false);
-				triggerList.Add(trigger);
+				if(! playSoundsFromFile)
+				{
+					Trigger trigger  = new Trigger(Trigger.Modes.ENCODER, i, false);
+					triggerList.Add(trigger);
+				}
+
 				continue;
 			}
 
@@ -854,6 +885,12 @@ public abstract class EncoderCapture
 	public void Finish() {
 		finish = true;
 	}
+
+	//used on inertialIM
+	public int Sum {
+		get { return sum; }
+	}
+
 }
 
 
@@ -996,6 +1033,8 @@ public class EncoderCaptureInertial : EncoderCapture
 
 public class EncoderCaptureIMCalc : EncoderCapture
 {
+	public static int InactivityEndTime = 3; //end at 3 segons of inactivity
+
 	public EncoderCaptureIMCalc() 
 	{
 	}
@@ -1003,13 +1042,15 @@ public class EncoderCaptureIMCalc : EncoderCapture
 	protected override void initSpecific()
 	{
 		realHeightG = 2 * 500 ; //.5 meter up / .5 meter down
+		IMCalcOscillations = 0;
 	}
 	
 	// on IMCalc we don't need to send data to R and get curves we will call R at the end
-	protected override bool shouldSendCurve() {
+	protected override bool shouldSendCurve()
+	{
+		IMCalcOscillations ++;
 		return false;
 	}
-	
 }
 
 /*
