@@ -57,6 +57,8 @@ public class EventExecute
 	}
 	protected eventType needUpdateGraphType;
 	
+	protected bool needCallTrackDone;
+	protected bool needCheckIfTrackEnded; //Races with double contacts wait some ms to see if other contact appears
 	protected bool needShowCountDown;	//RSA
 
 	//protected string syncMessage;
@@ -82,6 +84,8 @@ public class EventExecute
 
 	protected ExecutingGraphData egd;
 	
+	//for runs
+	public RunPhaseTimeList runPTL;
 
 
 	//better as private and don't inherit, don't know why
@@ -140,8 +144,6 @@ public class EventExecute
 	//on animation lights and discriminative should be false
 	public bool StartIn = true;
 	public Gtk.Button FakeButtonReactionTimeStart;
-	
-	
 
 	//protected EventExecuteWindow eventExecuteWin;
 	//protected ChronoJumpWindow app1;
@@ -225,7 +227,11 @@ public class EventExecute
 		//then thread is dead
 
 		if ( ! thread.IsAlive || cancel) {
-			LogB.ThreadEnding(); 
+			LogB.ThreadEnding();
+
+			//don't show any of the runChangeImage icons
+			runChangeImageForceHide();
+
 			fakeButtonThreadDyed.Click();
 
 			LogB.ThreadEnded(); 
@@ -233,6 +239,7 @@ public class EventExecute
 		}
 	
 		Thread.Sleep (50);
+		//Thread.Sleep (25);
 		//LogB.Debug(thread.ThreadState.ToString());
 		return true;
 	}
@@ -314,7 +321,26 @@ public class EventExecute
 			egd.Button_finish.Sensitive = true;
 			needSensitiveButtonFinish = false;
 		}
-		
+
+		// races specific --------------------------------->
+
+		runChangeImageIfNeeded();
+
+		updateRunPhaseInfoManage();
+
+		//Race track with DoubleContacts mode NONE
+		if(needCallTrackDone)
+		{
+			trackDone();
+			needCallTrackDone = false;
+		}
+		//Race track with DoubleContacts mode != NONE
+		if(needCheckIfTrackEnded && lastTfCheckTimeEnded())
+		{
+			trackDone();
+			needCheckIfTrackEnded = false;
+		}
+
 		//RSA
 		if(needShowCountDown) 
 		{
@@ -327,6 +353,7 @@ public class EventExecute
 			needShowFeedbackMessage = false;
 		}
 		
+		// <-------------------------- end of races specific
 		
 		//check if it should finish by time
 		if(shouldFinishByTime()) {
@@ -335,6 +362,8 @@ public class EventExecute
 		} 
 	}
 	
+	// races specific --------------------------------->
+
 	private void runATouchPlatform() {
 		UtilGtk.PrintLabelWithTooltip(egd.Label_message, feedbackMessage);
 	}
@@ -342,7 +371,30 @@ public class EventExecute
 	public void RunANoStrides() {
 		UtilGtk.PrintLabelWithTooltip(egd.Label_message, feedbackMessage);
 	}
-	
+
+	protected virtual bool lastTfCheckTimeEnded()
+	{
+		return true;
+	}
+
+	protected virtual void runChangeImageIfNeeded()
+	{
+	}
+
+	protected virtual void runChangeImageForceHide()
+	{
+	}
+
+	protected virtual void updateRunPhaseInfoManage()
+	{
+	}
+
+	protected virtual void trackDone()
+	{
+	}
+
+	// <-------------------------- end of races specific
+
 	protected void progressBarEventOrTimePreExecution (bool isEvent, bool percentageMode, double events) 
 	{
 		if (isEvent) 
@@ -473,7 +525,17 @@ public class EventExecute
 	
 	public virtual void Manage2() {
 	}
-	
+
+	public virtual string GetInspectorMessages()
+	{
+		return "";
+	}
+
+	public RunPhaseTimeList RunPTL
+	{
+		get { return runPTL; }
+	}
+
 	//from confirm_window cancel button (thread has not started)
 	//this is NOT called when a event has started and user click on "Cancel"
 	protected void cancel_event_before_start(object o, EventArgs args)
@@ -545,3 +607,62 @@ public class EventExecute
 	   
 }
 
+public class PhaseTime
+{
+	private bool contactIn;
+	private double duration;
+
+	public PhaseTime (bool contactIn, double duration)
+	{
+		this.contactIn = contactIn;
+		this.duration = duration;
+	}
+
+	public override string ToString()
+	{
+		string strMode = "IN (TC)";
+		if(! contactIn)
+			strMode = "OUT (TF)";
+
+		//TODO: use a printf mode to have always same digits
+		return "\n" + Math.Round(Util.DivideSafe(duration, 1000.0), 3) + " - " + strMode;
+	}
+
+	public bool IsContact
+	{
+		get { return contactIn; }
+	}
+	public double Duration
+	{
+		get { return duration; }
+	}
+}
+
+public class InOut
+{
+	private bool contactIn;
+	private DateTime dt;
+	private string message;
+
+	public InOut (bool contactIn, DateTime dt, string message)
+	{
+		this.contactIn = contactIn;
+		this.dt = dt;
+		this.message = message;
+	}
+
+	public override string ToString()
+	{
+		string str = "\n- ";
+		if(contactIn)
+			str += "IN / ";
+		else
+			str += "OUT / ";
+
+		str += dt.ToShortTimeString();
+		if(message != "")
+			str += " / " + message;
+
+		return str;
+	}
+}
