@@ -20,7 +20,7 @@
 
 using System;
 using System.Data;
-
+using System.Collections.Generic; //List
 using System.Threading;
 using System.IO.Ports;
 using Mono.Unix;
@@ -28,7 +28,7 @@ using Mono.Unix;
 public class RunExecute : EventExecute
 {
 	protected double distance;
-	protected double time;
+	protected double trackTime;
 	protected bool startIn;
 	
 	protected Chronopic cp;
@@ -47,10 +47,31 @@ public class RunExecute : EventExecute
 	protected Constants.DoubleContact checkDoubleContactMode;
 	protected int checkDoubleContactTime;
 	
-	protected bool speedStartArrival; //if speedStartArrival then race time includes reaction time
+	protected bool speedStart; 	  //if we started before the contact
+	protected bool speedStartArrival; //(preferences) if true then race time includes reaction time
 	protected bool measureReactionTime;
 	protected double reactionTimeMS; //reaction time in milliseconds
-	
+
+	//double contacts stuff
+	protected double timestampDCFlightTimes; 	//sum of the flight times that happen in small time
+	protected double timestampDCContactTimes; 	//sum of the contact times that happen in small time
+	protected double timestampDCn; 			//number of flight times in double contacts period
+	protected static double lastTc;			//useful to know time on contact platform because intervalTimesString does not differentiate
+	protected static double lastTf; 		//used when no double contacts mode
+	protected static DateTime timerLastTf; 		//this two will be protected and in runSimpleExecute
+
+	//static because they are used on both threads at the same time
+	protected static RunExecuteInspector runEI;
+	protected static RunDoubleContact runDC;
+	protected static RunChangeImage runChangeImage;
+	protected static bool success;
+	protected RunExecuteInspector.Types runEIType;
+
+	protected Gtk.Image image_run_execute_running;
+	protected Gtk.Image image_run_execute_photocell;
+
+//	protected bool firstTrackDone;
+
 	public RunExecute() {
 	}
 
@@ -61,7 +82,8 @@ public class RunExecute : EventExecute
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			double progressbarLimit, ExecutingGraphData egd,
 			Constants.DoubleContact checkDoubleContactMode, int checkDoubleContactTime, 
-			bool speedStartArrival, bool measureReactionTime
+			bool speedStartArrival, bool measureReactionTime,
+			Gtk.Image image_run_execute_running, Gtk.Image image_run_execute_photocell
 			)
 	{
 		this.personID = personID;
@@ -83,6 +105,8 @@ public class RunExecute : EventExecute
 		this.checkDoubleContactTime = checkDoubleContactTime;
 		this.speedStartArrival = speedStartArrival;	
 		this.measureReactionTime = measureReactionTime;
+		this.image_run_execute_running = image_run_execute_running;
+		this.image_run_execute_photocell = image_run_execute_photocell;
 
 		reactionTimeMS = 0;
 
@@ -93,6 +117,9 @@ public class RunExecute : EventExecute
 		
 		needUpdateEventProgressBar = false;
 		needUpdateGraph = false;
+		needCallTrackDone = false;
+		needCheckIfTrackEnded = false;
+		runEIType = RunExecuteInspector.Types.RUN_SIMPLE;
 		
 		//initialize eventDone as a Run	
 		eventDone = new Run();
@@ -127,6 +154,7 @@ public class RunExecute : EventExecute
 			platformState = chronopicInitialValue(cp);
 		
 		LogB.Debug("MANAGE(b)!!!!");
+		runChangeImage = new RunChangeImage();
 
 		//you can start ON or OFF the platform, 
 		//we record always de TF (or time between we abandonate the platform since we arrive)
@@ -138,6 +166,7 @@ public class RunExecute : EventExecute
 			loggedState = States.ON;
 			startIn = true;
 			runPhase = runPhases.PLATFORM_INI_NO_TIME;
+			runChangeImage.Current = RunChangeImage.Types.PHOTOCELL;
 		} else if (platformState==Chronopic.Plataforma.OFF) {
 			feedbackMessage = Catalog.GetString("You are OUT, RUN when prepared!");
 			needShowFeedbackMessage = true; 
@@ -146,6 +175,7 @@ public class RunExecute : EventExecute
 			loggedState = States.OFF;
 			startIn = false;
 			runPhase = runPhases.PRE_RUNNING;
+			runChangeImage.Current = RunChangeImage.Types.RUNNING;
 		}
 		else { //UNKNOW (Chronopic disconnected, port changed, ...)
 			chronopicHasBeenDisconnected();
@@ -185,161 +215,399 @@ public class RunExecute : EventExecute
 		LogB.ThreadStart(); 
 		thread.Start(); 
 	}
-	
+
+	protected void timestampDCInitValues()
+	{
+		timestampDCFlightTimes = 0;
+		timestampDCContactTimes = 0;
+		timestampDCn = 0;
+	}
+
 	protected override void waitEvent ()
 	{
+		success = false;
+		timerCount = 0;
+		lastTc = 0;
+		//firstTrackDone = false;
+
 		double timestamp = 0;
-		double timestampFirstContact = 0; //used when runPhase == runPhases.PLATFORM_INI_YES_TIME;
-
-		double timestampDCFlightTimes = -1; //sum of the flight times that happen in small time
-		double timestampDCContactTimes = -1;//sum of the contact times that happen in small time
-		double timestampDCn = 0; //number of flight times
-
-		bool success = false;
 		bool ok;
 
+		timestampDCInitValues();
+		timerLastTf = DateTime.MinValue;
+
 		//prepare variables to allow being cancelled or finished
 		if(! simulated)
 			Chronopic.InitCancelAndFinish();
 
+		runEI = new RunExecuteInspector(
+				runEIType,
+				speedStartArrival,
+				checkDoubleContactMode,
+				checkDoubleContactTime
+				);
+		runEI.ChangePhase(RunExecuteInspector.Phases.START);
+
+		//initialize runDC
+		runDC = new RunDoubleContact(
+				checkDoubleContactMode,
+				checkDoubleContactTime,
+				speedStartArrival
+				);
+		runPTL = new RunPhaseTimeList(checkDoubleContactTime);
+
+		bool firstFromChronopicReceived = false;
+		bool exitWaitEventBucle = false;
 		do {
 			if(simulated)
 				ok = true;
 			else 
 				ok = cp.Read_event(out timestamp, out platformState);
 			
-			//if (ok) {
-			if (ok && !cancel) {
+			if (ok && ! cancel && ! finish)
+			{
+				if( ! firstFromChronopicReceived )
+				{
+					speedStart = has_arrived();
+					runDC.SpeedStart = has_arrived();
+					runPTL.SpeedStart = has_arrived();
+					firstFromChronopicReceived = true;
+				}
+
+				onlyInterval_CalculateDistanceIntervalFixed();
+
 				//LogB.Information("timestamp:" + timestamp);
-				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) {
-					//has arrived
+				if (has_arrived()) // timestamp is tf
+				{
 					loggedState = States.ON;
-					
-					if(runPhase == runPhases.PRE_RUNNING) {
+					runChangeImage.Current = RunChangeImage.Types.PHOTOCELL;
+
+					onlyInterval_NeedShowCountDownFalse();
+
+					if(runPhase == runPhases.PRE_RUNNING)
+					{
 						if(speedStartArrival || measureReactionTime) {
 							runPhase = runPhases.PLATFORM_INI_YES_TIME;
+							//run starts
 							initializeTimer(); //timerCount = 0
-						} else
+							runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+								"TimerStart");
+						} else {
 							runPhase = runPhases.PLATFORM_INI_NO_TIME;
-						
-						updateProgressBar = new UpdateProgressBar (
-								true, //isEvent
-								true, //tracksLimited: percentageMode
-								1 //just reached platform, phase 1/3
-								);  
-						needUpdateEventProgressBar = true;
+							runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+								"No timer start until leave plaform");
+						}
+
+						feedbackMessage = "";
+						needShowFeedbackMessage = true;
 					} else {
-						//run finished: 
-						//if started outside (behind platform) it's the second arrive
-						//if started inside: it's the first arrive
+						/*
+						 * on simple runs, run MAYBE finished:
+						 * if started outside (behind platform) it's the second arrive
+						 * if started inside: it's the first arrive
+						 * MAYBE finished because: with new 1.8.1 code, we wait checkTime * 1,5 to see if there are more contacts
+						 */
+						runPhase = runPhases.RUNNING;
 						
 						if(simulated)
 							timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
 
 						//prevent double contact stuff
-						if(checkDoubleContactMode != Constants.DoubleContact.NONE) {
-							if(timestamp <= checkDoubleContactTime) {
-								/*
-								   when checking double contact
-								   first time that timestamp < checkDoubleContactTime
-								   and we arrived (it's a flight time)
-								   record this time as timestampDCFlightTimes
-								 */
-								timestampDCn ++;
-								timestampDCFlightTimes += timestamp;
-							}
-							else {
-								if(timestampDCn > 0) {
-									if(checkDoubleContactMode == 
-											Constants.DoubleContact.FIRST) {
-										/* user want first flight time,
-										   then add all DC times*/
-										timestamp += timestampDCFlightTimes + 
-											timestampDCContactTimes;
-									}
-									else if(checkDoubleContactMode == 
-											Constants.DoubleContact.LAST) {
-										//user want last flight time, take that
-										// It doesn't change the timestamp so this is the same as:
-										// timestamp = timestamp;
-									}
-									else {	/* do the avg of all flights and contacts
-										   then add to last timestamp */
-										timestamp += 
-											(timestampDCFlightTimes + 
-											 timestampDCContactTimes) 
-											/ timestampDCn;
-									}
-								}
-								success = true;
-							}
+						if(runDC.UseDoubleContacts())
+						{
+							runDC.DoneTF (timestamp);
+							timerLastTf = DateTime.Now;
+							needCheckIfTrackEnded = true;
+						} else
+						{
+							lastTf = timestamp;
+							//trackDone();
+							needCallTrackDone = true;
 						}
-						
-						if(checkDoubleContactMode == Constants.DoubleContact.NONE)
-							success = true;
 
-						if(success) {
-							runPhase = runPhases.PLATFORM_END;
+						runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+								string.Format("Arrived (preparing track) timestamp: {0}", Math.Round(timestamp, 3)));
 
-							//add the first contact time if PLATFORM_INI_YES_TIME
-							if(timestampFirstContact > 0)
-							{
-								if(measureReactionTime)
-									reactionTimeMS = timestampFirstContact;
-
-								// measuringReactionTime or not, if speedStartArrival, timestamp should include timpestampFirstContact
-								if(speedStartArrival)
-									timestamp += timestampFirstContact;
-							}
-
-							time = timestamp / 1000.0;
-							write();
-
-							//success = true;
-
-							updateProgressBar = new UpdateProgressBar (
-									true, //isEvent
-									true, //percentageMode
-									//percentageToPass
-									3
-									);  
-							needUpdateEventProgressBar = true;
-						}
+						runPTL.AddTF(timestamp);
 					}
 				}
-				else if (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON) {
-					//it's out, was inside (= has abandoned platform)
-					//don't record time
-						
-					//change the automata state
+				else if (has_lifted()) // timestamp is tc
+				{
 					loggedState = States.OFF;
+					runChangeImage.Current = RunChangeImage.Types.RUNNING;
 
-					if(checkDoubleContactMode != Constants.DoubleContact.NONE && timestampDCn > 0)
-						timestampDCContactTimes += timestamp;
-					else {
-						if(runPhase == runPhases.PLATFORM_INI_YES_TIME)
-							timestampFirstContact = timestamp;
-						else if(runPhase == runPhases.PLATFORM_INI_NO_TIME)
-							initializeTimer(); //timerCount = 0
+					lastTc = 0;
 
-						//update event progressbar
-						updateProgressBar = new UpdateProgressBar (
-								true, //isEvent
-								true, //percentageMode
-								2 //normal run, phase 2/3
-								);  
-						needUpdateEventProgressBar = true;
+					if(runPhase == runPhases.PLATFORM_INI_NO_TIME)
+					{
+						//run starts
+						initializeTimer(); //timerCount = 0
+						runEI.ChangePhase(RunExecuteInspector.Phases.OUT, "Timer start");
+
+						/*
+						 * Stored the TC because we need it to decide
+						 * if time will starts after this contact or
+						 * other double contacts that will come just after
+						 * depending on biggest tc
+						 */
+						runDC.DoneTC(timestamp, false);
+						runPTL.AddTC(timestamp);
+
+						feedbackMessage = "";
+						needShowFeedbackMessage = true;
+					}
+					else if(runPhase == runPhases.PLATFORM_INI_YES_TIME)
+					{
+						if(measureReactionTime)
+							reactionTimeMS = timestamp;
+
+						if(speedStartArrival)
+						{
+							lastTc = timestamp / 1000.0;
+							runEI.ChangePhase(RunExecuteInspector.Phases.OUT,
+								string.Format("SpeedStartArrival, tc = {0}", Math.Round(lastTc, 3)));
+							runDC.DoneTC(timestamp, true);
+							runPTL.AddTC(timestamp);
+						}
 
 						feedbackMessage = "";
 						needShowFeedbackMessage = true; 
+					} else {
+						runEI.ChangePhase(RunExecuteInspector.Phases.OUT,
+								string.Format("SpeedStartArrival, timestamp = {0}", timestamp));
 
-						runPhase = runPhases.RUNNING;
+						if(runDC.UseDoubleContacts())
+							runDC.DoneTC(timestamp, true);
+						else
+							lastTc = timestamp / 1000.0;
+
+						runPTL.AddTC(timestamp);
+
+						onlyInterval_SetRSAVariables();
 					}
+
+					runPhase = runPhases.RUNNING;
 				}
 			}
-		} while ( ! success && ! cancel );
+
+			exitWaitEventBucle = false;
+			if(success || cancel || finish)
+			{
+				exitWaitEventBucle = waitToExitWaitEventBucle();
+				runChangeImage.Current = RunChangeImage.Types.NONE;
+			}
+
+		} while ( ! exitWaitEventBucle );
+
+		onlyInterval_FinishWaitEventWrite();
+	}
+
+	protected bool has_arrived()
+	{
+		return (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF);
+	}
+	protected bool has_lifted()
+	{
+		return (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON);
 	}
 	
+	/* only run interval functions */
+
+	protected virtual void onlyInterval_CalculateDistanceIntervalFixed()
+	{
+	}
+	protected virtual void onlyInterval_NeedShowCountDownFalse()
+	{
+	}
+	protected virtual void onlyInterval_SetRSAVariables()
+	{
+	}
+	protected virtual void onlyInterval_FinishWaitEventWrite()
+	{
+	}
+
+	/* end of only run interval functions */
+
+	protected bool waitToExitWaitEventBucle()
+	{
+		if(runDC.UseDoubleContacts())
+		{
+			LogB.Information(string.Format("success: {0}, cancel: {1}, finish: {2}", success, cancel, finish));
+			while(needCheckIfTrackEnded)
+			{
+				LogB.Information("WAITING 100 MS TO EXIT BUCLE");
+				//TODO: checks what happens with cancel... in the pulse thread, will change this boolean? needCheckIfTrackEnded
+				//TODO: also think on what happens if needCheckIfTrackEnded never gets negative
+				Thread.Sleep(100);
+			}
+
+			return true;
+		}
+		else
+			return true;
+	}
+
+	protected override void runChangeImageIfNeeded()
+	{
+		if(! runChangeImage.ShouldBeChanged())
+			return;
+
+		if(runChangeImage.Current == RunChangeImage.Types.RUNNING)
+		{
+			image_run_execute_running.Visible = true;
+			image_run_execute_photocell.Visible = false;
+		}
+		else if(runChangeImage.Current == RunChangeImage.Types.PHOTOCELL)
+		{
+			image_run_execute_running.Visible = false;
+			image_run_execute_photocell.Visible = true;
+		} else
+		{
+			image_run_execute_running.Visible = false;
+			image_run_execute_photocell.Visible = false;
+		}
+	}
+
+	protected override void runChangeImageForceHide()
+	{
+		image_run_execute_running.Visible = false;
+		image_run_execute_photocell.Visible = false;
+	}
+
+	protected override void updateRunPhaseInfoManage()
+	{
+		//check if it's defined at beginning of race
+		if(runDC != null)
+			runDC.UpdateList();
+	}
+
+	protected override bool lastTfCheckTimeEnded()
+	{
+		//LogB.Information("In lastTfCheckTimeEnded()");
+		TimeSpan span = DateTime.Now - timerLastTf;
+		if(span.TotalMilliseconds > checkDoubleContactTime * 1.5)
+		{
+			timerLastTf = DateTime.Now;
+			LogB.Information("lastTfCheckTimeEnded: success");
+			return true;
+		}
+		//LogB.Information("... ended NOT success");
+		return false;
+	}
+
+
+	//big change in 1.8.1: this is called from GTK thread
+	//so don't write to SQL here
+	//and use static variables where needed
+	protected override void trackDone()
+	{
+		LogB.Information("In trackDone() A");
+
+		runDC.TrackDoneHasToBeCalledAgain = false;
+		if(success)
+			return;
+
+		LogB.Information("In trackDone() B");
+		//double myTrackTime = 0;
+		if(runDC.UseDoubleContacts())
+		{
+			if(! runDC.FirstTrackDone)
+			{
+				//TODO: take care because maybe more data can come than just the start, eg:
+				//
+				//_ __ _   (300ms < > 450ms)      _ _ _        (450ms...)
+				//
+				//all above line can be processed at once
+				//so IsStartDoubleContact will be false
+				//because all the tc,tf are processed and tf in the middle is greater than 300ms
+				//so start will be marked in the first _
+				//when should be done in the second _
+				if(runDC.IsStartDoubleContact())
+				{
+					int posOfBiggestTC = 0;
+					if(speedStart)
+						posOfBiggestTC = runDC.GetPosOfBiggestTC(false);
+
+					if(speedStart && ! speedStartArrival) 		//speed start and leaving
+						runPTL.FirstRPIs = posOfBiggestTC +1;
+					else if(speedStart && speedStartArrival) 	//speed start and arrival
+						runPTL.FirstRPIs = posOfBiggestTC;
+					else 						//no speed start (measure on leaving first contact)
+						runPTL.FirstRPIs = posOfBiggestTC +1;
+
+					runDC.UpdateStartPos(posOfBiggestTC);
+					return;
+				}
+				else
+				{
+					//if leaving: start pos will be on first TF
+					if( runPTL.FirstRPIs == 0 && (! speedStart || (speedStart && ! speedStartArrival)) )
+					{
+						runPTL.FirstRPIs = 1;
+						runDC.UpdateStartPos(1);
+					}
+				}
+
+			}
+
+			trackTime = runDC.GetTrackTimeInSecondsAndUpdateStartPos(); //will come in seconds
+			runDC.FirstTrackDone = true;
+		}
+		else {
+			//note in double contacts mode timestamp can have added
+			//DCFlightTimes and DCContactTimes.
+			//So contact time is not only on lastTc
+			trackTime = lastTc + lastTf/1000.0;
+		}
+
+		LogB.Information("trackTime: " + trackTime.ToString());
+		//solve possible problems of bad copied data between threads on start
+		if(trackTime == 0)
+			return;
+
+		runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+				string.Format("; timestamp: {0}; <b>trackTime: {1}</b>",
+					Math.Round(lastTf/1000.0, 3), Math.Round(trackTime, 3)));
+
+		trackDoneRunSpecificStuff();
+
+		/*
+		 * searching GetPosOfBiggestTC maybe two different tracks found
+		 * so call this method again to process the other
+		 */
+		if(! success && runDC.TrackDoneHasToBeCalledAgain)
+			trackDone();
+
+	}
+
+	protected virtual void trackDoneRunSpecificStuff ()
+	{
+		LogB.Information(string.Format("RACE (simple) TC: {0}; TV: {1}; TOTALTIME: {2}", lastTc, lastTf/1000.0, trackTime));
+
+		/*
+		double time = timestamp / 1000.0;
+
+		runEI.ChangePhase(RunExecuteInspector.Phases.IN, runEIString +
+				string.Format("; timestamp: {0}; <b>trackTime: {1}</b>",
+					Math.Round(timestamp/1000.0, 3), Math.Round(time, 3)));
+					*/
+
+		write();
+		success = true;
+
+		//as we will be on waitEvent do { ok = cp.Read_event ... }
+		//call this to end Read_cambio called by Read_event
+		Chronopic.FinishDo();
+
+		updateProgressBar = new UpdateProgressBar (
+				true, //isEvent
+				true, //percentageMode
+				//percentageToPass
+				3
+				);
+		needUpdateEventProgressBar = true;
+	}
+
 	protected override bool shouldFinishByTime() {
 		return false; //this kind of events (simple runs) cannot be finished by time
 	}
@@ -393,7 +661,7 @@ public class RunExecute : EventExecute
 
 	protected override void write()
 	{
-		LogB.Information(string.Format("TIME: {0}", time.ToString()));
+		LogB.Information(string.Format("tracktime: {0}", trackTime.ToString()));
 		
 		/*
 		string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + " " + 
@@ -414,7 +682,7 @@ public class RunExecute : EventExecute
 			// D: distance between 3d and 9th stair
 			double weight = SqlitePersonSession.SelectAttribute(false, personID, sessionID, Constants.Weight);
 			double distanceMeters = distance / 1000;
-			description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMeters / time).ToString(), pDN) + " (Watts)";
+			description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMeters / trackTime).ToString(), pDN) + " (Watts)";
 		} else if(type == "Gesell-DBT") 
 			description = "0";
 
@@ -424,16 +692,16 @@ public class RunExecute : EventExecute
 		string table = Constants.RunTable;
 
 		uniqueID = SqliteRun.Insert(false, table, "NULL", personID, sessionID, 
-				type, distance, time, description, 
+				type, distance, trackTime, description,
 				Util.BoolToNegativeInt(simulated), 
 				!startIn	//initialSpeed true if not startIn
 				); 
 		
 		//define the created object
-		eventDone = new Run(uniqueID, personID, sessionID, type, distance, time, description, Util.BoolToNegativeInt(simulated), !startIn); 
+		eventDone = new Run(uniqueID, personID, sessionID, type, distance, trackTime, description, Util.BoolToNegativeInt(simulated), !startIn);
 
 		//app1.PrepareRunSimpleGraph(time, distance/time);
-		PrepareEventGraphRunSimpleObject = new PrepareEventGraphRunSimple(time, distance/time, sessionID, personID, table, type);
+		PrepareEventGraphRunSimpleObject = new PrepareEventGraphRunSimple(trackTime, distance/trackTime, sessionID, personID, table, type);
 		needUpdateGraphType = eventType.RUN;
 		needUpdateGraph = true;
 		
@@ -454,6 +722,14 @@ public class RunExecute : EventExecute
 		return Util.TrimDecimals(rtimeMS / 1000.0, ndec) + " ms (" + str + ")";
 	}
 
+	public override string GetInspectorMessages()
+	{
+		if(runPTL != null)
+			return runEI.ToString() + "\n\n" + runPTL.ToString() + "\n\n" + runPTL.InListForPaintingToString();
+		else
+			return runEI.ToString();
+	}
+
 	public string RunnerName
 	{
 		get { return SqlitePerson.SelectAttribute(personID, Constants.Name); }
@@ -468,18 +744,21 @@ public class RunIntervalExecute : RunExecute
 	double distanceTotal;
 	double timeTotal;
 	double distanceInterval;
-	string intervalTimesString;
-	double tracks; //double because if we limit by time (runType tracksLimited false), we do n.nn tracks
 	string limited; //the teorically values, eleven runs: "11=R" (time recorded in "time"), 10 seconds: "10=T" (tracks recorded in tracks)
 	double limitAsDouble;	//-1 for non limited (unlimited repetitive run until "finish" is clicked)
 	bool tracksLimited;
 
-
 	string distancesString; //if distances are variable (distanceInterval == -1), this is used
 	double distanceIntervalFixed; //if distanceInterval == -1, then Fixed is the corresponding base on distancesString
-	double lastTc;		//useful to know time on contact platform because intervalTimesString does not differentiate
+
+	//static because they are used on both threads at the same time
+	static double tracks; //double because if we limit by time (runType tracksLimited false), we do n.nn tracks
+	static string intervalTimesString;
+	//since trackDone is called by PulseGTK (onTimer)
 							
-	bool RSABellDone;
+	private bool RSABellDone;
+	private string equal;
+	private int countForSavingTempTable;
 
 	//private Chronopic cp;
 
@@ -493,7 +772,8 @@ public class RunIntervalExecute : RunExecute
 			RepetitiveConditionsWindow repetitiveConditionsWin,
 			double progressbarLimit, ExecutingGraphData egd ,
 			Constants.DoubleContact checkDoubleContactMode, int checkDoubleContactTime, 
-			bool speedStartArrival, bool measureReactionTime
+			bool speedStartArrival, bool measureReactionTime,
+			Gtk.Image image_run_execute_running, Gtk.Image image_run_execute_photocell
 			)
 	{
 		this.personID = personID;
@@ -534,6 +814,8 @@ public class RunIntervalExecute : RunExecute
 		this.checkDoubleContactTime = checkDoubleContactTime;
 		this.speedStartArrival = speedStartArrival;	
 		this.measureReactionTime = measureReactionTime;
+		this.image_run_execute_running = image_run_execute_running;
+		this.image_run_execute_photocell = image_run_execute_photocell;
 
 		reactionTimeMS = 0;
 		reactionTimeIncludedStr = Catalog.GetString("Included on race time of first track");
@@ -546,238 +828,57 @@ public class RunIntervalExecute : RunExecute
 		
 		needUpdateEventProgressBar = false;
 		needUpdateGraph = false;
-		
+		needCallTrackDone = false;
+		needCheckIfTrackEnded = false;
+		runEIType = RunExecuteInspector.Types.RUN_INTERVAL;
+
 		timesForSavingRepetitive = 1; //number of times that this repetive event needs for being recorded in temporal table
 
+		//initialize variables
+		equal = "";
+		intervalTimesString = "";
+		distanceIntervalFixed = distanceInterval;
+		tracks = 0;
+		countForSavingTempTable = 0;
+
 		//initialize eventDone as a RunInterval
 		eventDone = new RunInterval();
 	}
 
 
-	protected override void waitEvent ()
+	/* only run interval functions */
+
+	protected override void onlyInterval_CalculateDistanceIntervalFixed()
 	{
-		double timestamp = 0;
-		bool success = false;
-		string equal = "";
-		
-		//initialize variables
-		intervalTimesString = "";
-		tracks = 0;
-		bool ok;
-		timerCount = 0;
-		//bool initialized = false;
-		int countForSavingTempTable = 0;
-		lastTc = 0;
-		distanceIntervalFixed = distanceInterval;
-
-		double timestampDCFlightTimes = -1; //sum of the flight times that happen in small time
-		double timestampDCContactTimes = -1;//sum of the contact times that happen in small time
-		double timestampDCn = 0; //number of flight times
-		
-		//prepare variables to allow being cancelled or finished
-		if(! simulated)
-			Chronopic.InitCancelAndFinish();
-
-		do {
-			if(simulated) 
-				ok = true;
-			else 
-				ok = cp.Read_event(out timestamp, out platformState);
-		
-	
-			if (ok && !cancel && !finish) {
-				if(distanceInterval == -1)
-					distanceIntervalFixed = Util.GetRunIVariableDistancesStringRow(distancesString, (int) tracks);
-
-				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) {
-					//has arrived
-					loggedState = States.ON;
+		if(distanceInterval == -1)
+			distanceIntervalFixed = Util.GetRunIVariableDistancesStringRow(distancesString, (int) tracks);
+	}
 					
-					//show RSA count down only on air		
-					needShowCountDown = false;
-					
-					//if we start out, and we arrive to the platform for the first time,
-					//don't record nothing
-					if(runPhase == runPhases.PRE_RUNNING) {
-						if(speedStartArrival || measureReactionTime) {
-							runPhase = runPhases.PLATFORM_INI_YES_TIME;
-							//run starts
-							initializeTimer(); //timerCount = 0
-						} else
-							runPhase = runPhases.PLATFORM_INI_NO_TIME;
+	protected override void onlyInterval_NeedShowCountDownFalse()
+	{
+		//show RSA count down only on air
+		needShowCountDown = false;
+	}
 
-						feedbackMessage = "";
-						needShowFeedbackMessage = true; 
-					}
-					else {
-						runPhase = runPhases.RUNNING;
-						//has arrived and not in the "running previous"
-						
-						//if interval run is "unlimited" not limited by tracks, nor time, 
-						//then play with the progress bar until finish button is pressed
-						
-						if(simulated)
-							timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
+	protected override void onlyInterval_SetRSAVariables()
+	{
+		double RSAseconds = Util.GetRunIVariableDistancesThisRowIsRSA(
+				distancesString, Convert.ToInt32(tracks));
+		if(RSAseconds > 0) {
+			RSABellDone = false;
+			needShowCountDown = true;
+		} else {
+			needShowCountDown = false;
+			feedbackMessage = "";
+			needShowFeedbackMessage = true;
+		}
+	}
 
-						if(checkDoubleContactMode != Constants.DoubleContact.NONE) {
-							if(timestamp <= checkDoubleContactTime) {
-								/*
-								   when checking double contact
-								   first time that timestamp < checkDoubleContactTime
-								   and we arrived (it's a flight time)
-								   record this time as timestampDCFlightTimes
-								 */
-								timestampDCn ++;
-								timestampDCFlightTimes += timestamp;
-								continue;
-							}
-							else {
-								if(timestampDCn > 0) {
-									if(checkDoubleContactMode == 
-											Constants.DoubleContact.FIRST) {
-										/* user want first flight time,
-										   then add all DC times*/
-										timestamp += timestampDCFlightTimes + 
-											timestampDCContactTimes;
-									}
-									else if(checkDoubleContactMode == 
-											Constants.DoubleContact.LAST) {
-										//user want last flight time, take that
-										// so we don't need to change timestamp. Or we could do (it triggers a warning):
-										// timestamp = timestamp;
-									}
-									else {	/* do the avg of all flights and contacts
-										   then add to last timestamp */
-										timestamp += 
-											(timestampDCFlightTimes + 
-											 timestampDCContactTimes) 
-											/ timestampDCn;
-									}
-								}
-							}
-						}
-
-						double myRaceTime = lastTc + timestamp/1000.0;
-
-						if(intervalTimesString.Length > 0) { equal = "="; }
-						intervalTimesString = intervalTimesString + equal + myRaceTime.ToString();
-						updateTimerCountWithChronopicData(intervalTimesString);
-						tracks ++;	
-
-						//save temp table if needed
-						countForSavingTempTable ++;
-						if(countForSavingTempTable == timesForSavingRepetitive) {
-								writeRunInterval(true); //tempTable
-								countForSavingTempTable = 0;
-						}
-					
-						if(limitAsDouble == -1) {
-							//has arrived, unlimited
-							updateProgressBar= new UpdateProgressBar (
-									true, //isEvent
-									true, //unlimited: activity mode
-									tracks
-									);  
-							needUpdateEventProgressBar = true;
-						}
-						else {
-							//has arrived, limited
-							if (tracksLimited) {
-								//has arrived, limited by tracks
-								if(tracks >= limitAsDouble) 
-								{
-									runPhase = runPhases.PLATFORM_END;
-
-									//finished
-									writeRunInterval(false); //tempTable = false
-									success = true;
-								}
-								//progressBarEventOrTimePreExecution(
-								updateProgressBar= new UpdateProgressBar (
-										true, //isEvent
-										true, //tracksLimited: percentageMode
-										tracks
-										);  
-								needUpdateEventProgressBar = true;
-							} else {
-								//has arrived, limited by time
-								updateProgressBar= new UpdateProgressBar (
-										true, //isEvent
-										false, //timeLimited: activity mode
-										tracks
-										);  
-								needUpdateEventProgressBar = true;
-							}
-						}
-
-						distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
-
-						//update graph
-						PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
-								distanceIntervalFixed, myRaceTime, intervalTimesString, 
-								distanceTotal, distancesString, startIn);
-
-						needUpdateGraphType = eventType.RUNINTERVAL;
-						needUpdateGraph = true;
-
-						//put button_finish as sensitive when first jump is done (there's something recordable)
-						if(tracks == 1)
-							needSensitiveButtonFinish = true;
-					}
-				}
-				else if (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON) {
-					//it's out, was inside (= has abandoned platform)
-							
-					if(runPhase == runPhases.PLATFORM_INI_NO_TIME) {
-						//run starts
-						initializeTimer();
-						lastTc = 0;
-
-						feedbackMessage = "";
-						needShowFeedbackMessage = true; 
-					} else if(runPhase == runPhases.PLATFORM_INI_YES_TIME)
-					{
-						lastTc = 0;
-						if(measureReactionTime)
-							reactionTimeMS = timestamp;
-
-						// measuringReactionTime or not, if speedStartArrival, 1st race time should include lastTc
-						if(speedStartArrival)
-							lastTc = timestamp/1000.0;
-
-						feedbackMessage = "";
-						needShowFeedbackMessage = true; 
-					} else {
-						if(checkDoubleContactMode != Constants.DoubleContact.NONE && timestampDCn > 0)
-							timestampDCContactTimes += timestamp;
-						else 
-							  lastTc = timestamp/1000.0;
-						
-						
-						//RSA
-						double RSAseconds = Util.GetRunIVariableDistancesThisRowIsRSA(
-								distancesString, Convert.ToInt32(tracks));
-						if(RSAseconds > 0) {
-							RSABellDone = false;
-							needShowCountDown = true;
-						} else {
-							needShowCountDown = false;
-							feedbackMessage = "";
-							needShowFeedbackMessage = true;
-						}
-
-					}
-
-						
-					runPhase = runPhases.RUNNING;
-
-					//change the automata state
-					loggedState = States.OFF;
-				}
-			}
-		} while ( ! success && ! cancel && ! finish );
-
-		if (finish) {
+	//TODO: is this needed at all with new 1.8.1 code?
+	protected override void onlyInterval_FinishWaitEventWrite()
+	{
+		if (finish)
+		{
 			runPhase = runPhases.PLATFORM_END;
 
 			//write();
@@ -791,6 +892,91 @@ public class RunIntervalExecute : RunExecute
 		}
 	}
 
+	/* end of only run interval functions */
+
+
+	protected override void trackDoneRunSpecificStuff ()
+	{
+		LogB.Information(string.Format("RACE TRACK ({0}) TC: {1}; TV: {2}; TOTALTIME: {3}", tracks, lastTc, lastTf/1000.0, trackTime));
+
+		if(intervalTimesString.Length > 0) { equal = "="; }
+		intervalTimesString = intervalTimesString + equal + trackTime.ToString();
+		updateTimerCountWithChronopicData(intervalTimesString);
+		tracks ++;
+
+		/*
+		 * Attention:
+		 * don't do this because we are on GTK thread right now
+		 * and here we are touching SQL
+		 *
+		//save temp table if needed
+		countForSavingTempTable ++;
+		if(countForSavingTempTable == timesForSavingRepetitive) {
+			writeRunInterval(true); //tempTable
+			countForSavingTempTable = 0;
+		}
+		*/
+
+		if(limitAsDouble == -1) {
+			//has arrived, unlimited
+			updateProgressBar= new UpdateProgressBar (
+					true, //isEvent
+					true, //unlimited: activity mode
+					tracks
+					);
+			needUpdateEventProgressBar = true;
+		}
+		else {
+			//has arrived, limited
+			if (tracksLimited) {
+				//has arrived, limited by tracks
+				if(tracks >= limitAsDouble) 
+				{
+					runPhase = runPhases.PLATFORM_END;
+
+					//finished
+					writeRunInterval(false); //tempTable = false
+					success = true;
+
+					//as we will be on waitEvent do { ok = cp.Read_event ... }
+					//call this to end Read_cambio called by Read_event
+			                Chronopic.FinishDo();
+				}
+				//progressBarEventOrTimePreExecution(
+				updateProgressBar= new UpdateProgressBar (
+						true, //isEvent
+						true, //tracksLimited: percentageMode
+						tracks
+						);
+				needUpdateEventProgressBar = true;
+			} else {
+				//has arrived, limited by time
+				updateProgressBar= new UpdateProgressBar (
+						true, //isEvent
+						false, //timeLimited: activity mode
+						tracks
+						);
+				needUpdateEventProgressBar = true;
+			}
+		}
+
+		distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
+
+		//update graph
+		PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
+				distanceIntervalFixed, trackTime, intervalTimesString,
+				distanceTotal, distancesString, startIn);
+
+		needUpdateGraphType = eventType.RUNINTERVAL;
+		needUpdateGraph = true;
+		//fakeButtonUpdateGraph.Click();
+
+		//put button_finish as sensitive when first jump is done (there's something recordable)
+		if(tracks == 1)
+			needSensitiveButtonFinish = true;
+	}
+
+
 	protected override string countDownMessage() {
 		double waitSeconds = Util.GetRunIVariableDistancesThisRowIsRSA(distancesString, Convert.ToInt32(tracks))
 			 - (timerCount - Util.GetTotalTime(intervalTimesString) - lastTc);
@@ -970,7 +1156,8 @@ public class RunIntervalExecute : RunExecute
 					);
 
 			//define the created object
-			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn); 
+			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString,
+					tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn); 
 
 			/*
 			string tempValuesString;
@@ -1002,60 +1189,6 @@ public class RunIntervalExecute : RunExecute
 			needEndEvent = true; //used for hiding some buttons on eventWindow, and also for updateTimeProgressBar here
 		}
 	}
-	
-	/*
-	public string IntervalTimesString
-	{
-		get { return intervalTimesString; }
-		set { intervalTimesString = value; }
-	}
-	
-	public double DistanceInterval
-	{
-		get { return distanceInterval; }
-		set { distanceInterval = value; }
-	}
-		
-	public double DistanceTotal
-	{
-		get { return distanceTotal; }
-		set { distanceTotal = value; }
-	}
-		
-	public double TimeTotal
-	{
-		get { return timeTotal; }
-		set { timeTotal = value; }
-	}
-		
-	public double Tracks
-	{
-		get { return tracks; }
-		set { tracks = value; }
-	}
-		
-	public string Limited
-	{
-		get { return limited; }
-		set { limited = value; }
-	}
 
-	public bool TracksLimited
-	{
-		get { return tracksLimited; }
-	}
-		
-	public override double Speed
-	{
-		get { 
-			//if(metersSecondsPreferred) 
-				return distanceTotal / timeTotal ; 
-			// else 
-			//	return (distanceTotal / timeTotal) * 3.6 ; 
-		}
-	}
-	*/
-		
 	~RunIntervalExecute() {}
 }
-
