@@ -31,6 +31,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_home1;
 	[Widget] Gtk.Image image_settings;
 	[Widget] Gtk.Image image_settings1;
+	[Widget] Gtk.Image image_minimize;
+	[Widget] Gtk.Image image_minimize1;
 	[Widget] Gtk.Image image_quit;
 	[Widget] Gtk.Image image_quit1;
 	[Widget] Gtk.Image image_quit2;
@@ -73,6 +75,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_add_test2;
 	[Widget] Gtk.Image image_add_test3;
 	[Widget] Gtk.Image image_add_test4;
+	[Widget] Gtk.Image image_test_inspect;
 
 	[Widget] Gtk.Image image_selector_start_jumps;
 	[Widget] Gtk.Image image_selector_start_runs;
@@ -81,6 +84,10 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_selector_start_other;
 	[Widget] Gtk.Image image_selector_start_cancel;
 
+	//run
+	[Widget] Gtk.Image image_run_execute_running;
+	[Widget] Gtk.Image image_run_execute_photocell;
+
 	//encoder images
 	[Widget] Gtk.Image image_top_eccon;
 	[Widget] Gtk.Image image_encoder_eccon_concentric;
@@ -113,6 +120,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_encoder_recalibrate;
 	[Widget] Gtk.Image image_encoder_triggers;
 	[Widget] Gtk.Image image_encoder_rhythm_rest;
+	[Widget] Gtk.Image image_encoder_analyze_mode_options;
+	[Widget] Gtk.Image image_encoder_analyze_mode_options_close;
+	[Widget] Gtk.Image image_encoder_analyze_cancel;
 
 	//force sensor
 	[Widget] Gtk.Image image_selector_start_force_sensor;
@@ -123,6 +133,11 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_force_sensor_calibrate;
 	[Widget] Gtk.Image image_force_sensor_open_folder;
 	[Widget] Gtk.Image image_force_sensor_check_version;
+	[Widget] Gtk.Image image_force_sensor_capture_adjust;
+	[Widget] Gtk.Image image_force_sensor_capture_adjust_close;
+	[Widget] Gtk.Image image_force_sensor_analyze_options;
+	[Widget] Gtk.Image image_force_sensor_analyze_options_close;
+	[Widget] Gtk.Image image_force_sensor_analyze_recalculate;
 
 	private void putNonStandardIcons()
 	{
@@ -153,6 +168,10 @@ public partial class ChronoJumpWindow
 		image_settings1.Pixbuf = pixbuf;
 		image_session_preferences.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_minimize.png");
+		image_minimize.Pixbuf = pixbuf;
+		image_minimize1.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_quit.png");
 		image_quit.Pixbuf = pixbuf;
 		image_quit1.Pixbuf = pixbuf;
@@ -208,6 +227,7 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
 		image_button_cancel.Pixbuf = pixbuf;
 		image_encoder_capture_cancel.Pixbuf = pixbuf;
+		image_encoder_analyze_cancel.Pixbuf = pixbuf;
 		image_selector_start_cancel.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_pin.png");
@@ -235,15 +255,23 @@ public partial class ChronoJumpWindow
 		image_add_test3.Pixbuf = pixbuf;
 		image_add_test4.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_test_inspect.png");
+		image_test_inspect.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_chronopic_connect.png");
 		image_chronopic_connect_contacts.Pixbuf = pixbuf;
 		image_chronopic_connect_encoder.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_recalculate.png");
 		image_recalculate.Pixbuf = pixbuf;
+		image_force_sensor_analyze_recalculate.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_build.png");
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_build_24.png");
 		image_encoder_configuration.Pixbuf = pixbuf;
+		image_force_sensor_capture_adjust.Pixbuf = pixbuf;
+		image_force_sensor_analyze_options.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_build_16.png");
+		image_encoder_analyze_mode_options.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_exercise.png");
 		image_encoder_exercise.Pixbuf = pixbuf;
@@ -284,6 +312,9 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
 		image_encoder_exercise1.Pixbuf = pixbuf;
+		image_force_sensor_analyze_options_close.Pixbuf = pixbuf;
+		image_encoder_analyze_mode_options_close.Pixbuf = pixbuf;
+		image_force_sensor_capture_adjust_close.Pixbuf = pixbuf;
 
 
 		/*
@@ -351,6 +382,11 @@ public partial class ChronoJumpWindow
 		image_mode_runs_small.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_multiple.png");
 		image_mode_runs_intervallic_small.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "run.png");
+		image_run_execute_running.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "run_photocell.png");
+		image_run_execute_photocell.Pixbuf = pixbuf;
 		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNamePulse);
 		image_mode_pulses_small.Pixbuf = pixbuf;
@@ -460,13 +496,14 @@ public partial class ChronoJumpWindow
 		UtilGtk.DeviceColors(viewport_chronopics, true);
 		UtilGtk.DeviceColors(viewport_chronopic_encoder, true);
 
+
 		//encoder
 		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_powerbars);
 		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_cross);
-		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_side);
-		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_single);
+		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_instantaneous);
 		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_neuromuscular_profile);
 		
+		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_position);
 		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_speed);
 		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_accel);
 		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_force);
@@ -480,6 +517,7 @@ public partial class ChronoJumpWindow
 		image_encoder_analyze_stats.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save.Pixbuf = pixbuf;
 		image_forcesensor_analyze_image_save.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save1.Pixbuf = pixbuf;
 		image_jumps_profile_save.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
 		image_encoder_signal_delete.Pixbuf = pixbuf;
@@ -527,10 +565,20 @@ public partial class ChronoJumpWindow
 		image_encoder_analyze_1RM.Pixbuf = pixbuf;
 		image_encoder_analyze_1RM_save.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeInstantaneousIcon);
+		image_encoder_analyze_instantaneous.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeSideIcon);
 		image_encoder_analyze_side.Pixbuf = pixbuf;
+		image_encoder_analyze_selected_side.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeSuperposeIcon);
+		image_encoder_analyze_superpose.Pixbuf = pixbuf;
+		image_encoder_analyze_selected_superpose.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeSingleIcon);
 		image_encoder_analyze_single.Pixbuf = pixbuf;
+		image_encoder_analyze_selected_single.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeAllSetIcon);
+		image_encoder_analyze_all_set.Pixbuf = pixbuf;
+		image_encoder_analyze_selected_all_set.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeNmpIcon);
 		image_encoder_analyze_nmp.Pixbuf = pixbuf;
 		
@@ -539,14 +587,21 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeEcconSeparatedIcon);
 		image_encoder_analyze_eccon_separated.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzePositionIcon);
+		image_encoder_analyze_position.Pixbuf = pixbuf;
+		image_encoder_analyze_show_SAFE_position.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeSpeedIcon);
 		image_encoder_analyze_speed.Pixbuf = pixbuf;
+		image_encoder_analyze_show_SAFE_speed.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeAccelIcon);
 		image_encoder_analyze_accel.Pixbuf = pixbuf;
+		image_encoder_analyze_show_SAFE_accel.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeForceIcon);
 		image_encoder_analyze_force.Pixbuf = pixbuf;
+		image_encoder_analyze_show_SAFE_force.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzePowerIcon);
 		image_encoder_analyze_power.Pixbuf = pixbuf;
+		image_encoder_analyze_show_SAFE_power.Pixbuf = pixbuf;
 		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeMeanIcon);
 		image_encoder_analyze_mean.Pixbuf = pixbuf;
