@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -75,16 +75,12 @@ public class EvaluatorWindow
 
 
 	[Widget] Gtk.Button button_accept;
-	[Widget] Gtk.Button button_cancel;
 	
 	string [] continents;
 	string [] continentsTranslated;
 	string [] countries;
 	string [] countriesTranslated;
-	string [] chronometers;
-	string [] devices;
-	string [] devicesTranslated;
-	
+
 	DialogCalendar myDialogCalendar;
 	DateTime dateTime;
 
@@ -102,7 +98,7 @@ public class EvaluatorWindow
 	{
 		//Setup (text, table, uniqueID);
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "evaluator_window", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "evaluator_window.glade", "evaluator_window", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
