@@ -23,6 +23,7 @@ using Gtk;
 using Glade;
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List
 using Mono.Unix;
 using Gdk; //for the EventMask
 using LongoMatch.Gui;
@@ -113,6 +114,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Notebook notebook_results_data;
 	
 	[Widget] Gtk.DrawingArea event_execute_drawingarea;
+	[Widget] Gtk.DrawingArea event_execute_drawingarea_run_simple_double_contacts;
 	/*
 	[Widget] Gtk.Box hbox_combo_graph_results_width;
 	[Widget] Gtk.Box hbox_combo_graph_results_height;
@@ -123,6 +125,7 @@ public partial class ChronoJumpWindow
 	//[Widget] Gtk.Alignment event_execute_alignment_drawingarea;
 	//static Gdk.Pixmap event_execute_pixmap = null;
 	Gdk.Pixmap event_execute_pixmap = null;
+	Gdk.Pixmap event_execute_run_simple_double_contacts_pixmap = null;
 	
 
 	string event_execute_label_simulated;
@@ -154,6 +157,7 @@ public partial class ChronoJumpWindow
 	Pango.Layout layoutSmall;
 	Pango.Layout layoutMid;
 	Pango.Layout layoutBig;
+	Pango.Layout layoutMid_run_simple;
 
 	static EventGraphConfigureWindow eventGraphConfigureWin;
 	
@@ -238,6 +242,9 @@ public partial class ChronoJumpWindow
 		layoutBig = new Pango.Layout (event_execute_drawingarea.PangoContext);
 		layoutBig.FontDescription = Pango.FontDescription.FromString ("Courier 14");
 		//layoutBig.Alignment = Pango.Alignment.Center; //doesn't work, see GetPixelSize below
+
+		layoutMid_run_simple = new Pango.Layout (event_execute_drawingarea_run_simple_double_contacts.PangoContext);
+		layoutMid_run_simple.FontDescription = Pango.FontDescription.FromString ("Courier 9");
 	}
 	private ExecutingGraphData event_execute_prepareForTest () 
 	{
@@ -455,7 +462,7 @@ public partial class ChronoJumpWindow
 
 		allocationXOld = allocation.Width;
 	}
-	
+
 	public void on_event_execute_drawingarea_expose_event(object o, ExposeEventArgs args)
 	{
 		/* in some mono installations, configure_event is not called, but expose_event yes. 
@@ -485,6 +492,55 @@ public partial class ChronoJumpWindow
 	}
 
 	
+	int allocationXOld_run_simple;
+	bool sizeChanged_run_simple;
+	public void on_event_execute_drawingarea_run_simple_double_contacts_expose_event(object o, ExposeEventArgs args)
+	{
+		/* in some mono installations, configure_event is not called, but expose_event yes.
+		 * Do here the initialization
+		 */
+
+		Gdk.Rectangle allocation = event_execute_drawingarea_run_simple_double_contacts.Allocation;
+		if(event_execute_run_simple_double_contacts_pixmap == null || sizeChanged_run_simple || allocation.Width != allocationXOld_run_simple) {
+			event_execute_run_simple_double_contacts_pixmap = new Gdk.Pixmap (event_execute_drawingarea_run_simple_double_contacts.GdkWindow, allocation.Width, allocation.Height, -1);
+			UtilGtk.ErasePaint(event_execute_drawingarea_run_simple_double_contacts, event_execute_run_simple_double_contacts_pixmap);
+
+			sizeChanged_run_simple = false;
+		}
+
+		Gdk.Rectangle area = args.Event.Area;
+
+		//sometimes this is called when pait is finished
+		//don't let this erase win
+		if(event_execute_run_simple_double_contacts_pixmap != null) {
+			args.Event.Window.DrawDrawable(event_execute_drawingarea_run_simple_double_contacts.Style.WhiteGC, event_execute_run_simple_double_contacts_pixmap,
+				area.X, area.Y,
+				area.X, area.Y,
+				area.Width, area.Height);
+		}
+
+		allocationXOld_run_simple = allocation.Width;
+	}
+
+	public void on_event_execute_drawingarea_run_simple_double_contacts_configure_event(object o, ConfigureEventArgs args)
+	{
+		Gdk.EventConfigure ev = args.Event;
+		Gdk.Window window = ev.Window;
+
+		Gdk.Rectangle allocation = event_execute_drawingarea_run_simple_double_contacts.Allocation;
+
+		if(event_execute_run_simple_double_contacts_pixmap == null || sizeChanged_run_simple || allocation.Width != allocationXOld_run_simple) {
+			event_execute_run_simple_double_contacts_pixmap = new Gdk.Pixmap (window, allocation.Width, allocation.Height, -1);
+
+			UtilGtk.ErasePaint(event_execute_drawingarea_run_simple_double_contacts, event_execute_run_simple_double_contacts_pixmap);
+
+			sizeChanged_run_simple = false;
+		}
+
+		allocationXOld_run_simple = allocation.Width;
+	}
+
+
 
 	// simple and DJ jump	
 	public void PrepareJumpSimpleGraph(PrepareEventGraphJumpSimple eventGraph, bool animate)
@@ -655,7 +711,14 @@ public partial class ChronoJumpWindow
 			
 
 	// run simple
+	// called from srg/gui/run updateGraphRunsSimple ()
 	public void PrepareRunSimpleGraph(PrepareEventGraphRunSimple eventGraph, bool animate)
+	{
+		PrepareRunSimpleGraph(eventGraph, animate, null);
+	}
+
+	//standard call
+	public void PrepareRunSimpleGraph(PrepareEventGraphRunSimple eventGraph, bool animate, RunPhaseTimeList runPTL)
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
@@ -693,9 +756,12 @@ public partial class ChronoJumpWindow
 		*/
 			minValue = eventGraphConfigureWin.Min;
 		//}
-			
+
+			UtilGtk.ClearDrawingArea(event_execute_drawingarea_run_simple_double_contacts,
+					event_execute_run_simple_double_contacts_pixmap);
+
 			paintRunSimple (event_execute_drawingarea, eventGraph,
-					maxValue, minValue, topMargin, bottomMargin, animate);
+					maxValue, minValue, topMargin, bottomMargin, animate, runPTL);
 		
 		
 		// -- refresh
@@ -707,7 +773,7 @@ public partial class ChronoJumpWindow
 	public void PrepareRunIntervalGraph(double distance, double lastTime, string timesString,
 			double distanceTotal, string distancesString,
 			bool startIn, bool volumeOn, Preferences.GstreamerTypes gstreamer,
-			RepetitiveConditionsWindow repetitiveConditionsWin)
+			RepetitiveConditionsWindow repetitiveConditionsWin, RunPhaseTimeList runPTL)
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
@@ -750,7 +816,7 @@ public partial class ChronoJumpWindow
 				lastTime, timesString, Util.GetAverage(timesString), 
 				maxValue, minValue, tracks, topMargin, bottomMargin,
 				Util.GetPosMax(timesString), Util.GetPosMin(timesString), startIn,
-				volumeOn, gstreamer, repetitiveConditionsWin);
+				volumeOn, gstreamer, repetitiveConditionsWin, runPTL);
 		
 		// -- refresh
 		event_execute_drawingarea.QueueDraw();
@@ -1110,22 +1176,46 @@ public partial class ChronoJumpWindow
 	}
 
 	private void paintRunSimple (Gtk.DrawingArea drawingarea, PrepareEventGraphRunSimple eventGraph,
-			double maxValue, double minValue, int topMargin, int bottomMargin, bool animate)
+			double maxValue, double minValue, int topMargin, int bottomMargin, bool animate,
+			RunPhaseTimeList runPTL)
 	{
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
 		
 		//fix problem on show graph at Chronojump start
-		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+		if(event_execute_drawingarea == null ||
+				event_execute_pixmap == null ||
+				event_execute_drawingarea_run_simple_double_contacts == null ||
+				event_execute_run_simple_double_contacts_pixmap == null)
 			return;
 
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
+		UtilGtk.ErasePaint(event_execute_drawingarea_run_simple_double_contacts, event_execute_run_simple_double_contacts_pixmap);
 		//writeMarginsText(maxValue, minValue, alto);
 		
 		//check now here that we will have not division by zero problems
 		if(maxValue - minValue <= 0)
 			return;
 		
+		double timeTotal = eventGraph.time;
+		// start of contact chunks
+		if(runPTL != null)
+		{
+			List<RunPhaseTimeListObject> runPTLInListForPainting = runPTL.InListForPainting();
+
+			double negativePTLTime = getRunSRunINegativePTLTime(runPTLInListForPainting);
+			double timeTotalWithExtraPTL = getRunSRunITimeTotalWithExtraPTLTime (timeTotal, runPTLInListForPainting, negativePTLTime);
+
+			LogB.Information(string.Format("timeTotal: {0}, negativePTLTime: {1}, timeTotalWithExtraPTL: {2}",
+						timeTotal, negativePTLTime, timeTotalWithExtraPTL));
+
+
+			int ancho2 = event_execute_drawingarea_run_simple_double_contacts.Allocation.Width;
+			paintRunSRunIContactChunks(event_execute_run_simple_double_contacts_pixmap, 20, ancho2, 0,
+					runPTLInListForPainting, timeTotal, timeTotalWithExtraPTL, negativePTLTime, true);
+		}
+		// end of contact chunks
+
 		/*
 		//paint reference guide black and green if needed
 		drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
@@ -1137,7 +1227,9 @@ public partial class ChronoJumpWindow
 		drawGuideOrAVG(pen_black_90, eventGraph.sessionMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 		drawGuideOrAVG(pen_black_discont, eventGraph.sessionAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 		drawGuideOrAVG(pen_magenta, eventGraph.personMAXAtSQLAllSessions, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
-		
+
+
+
 		//if currentPerson has not run on this session, 
 		// if has run on another session, magenta line: personMAXAtSQLAllSessions will be displayed
 		// if other persons have run on this session, eventGraph.sessionMAXAtSQL and eventGraph.sessionAVGAtSQL will be displayed
@@ -1180,7 +1272,8 @@ public partial class ChronoJumpWindow
 			
 		addUnitsToLabel("m/s");
 	}
-	
+
+
 	private void paintReactionTime (Gtk.DrawingArea drawingarea, PrepareEventGraphReactionTime eventGraph,
 			double maxValue, double minValue, int topMargin, int bottomMargin, bool animate)
 	{
@@ -1430,12 +1523,111 @@ public partial class ChronoJumpWindow
 			event_execute_label_jump_reactive_tf_tc_avg.Text = "0";
 	}
 
+	double getRunSRunINegativePTLTime (List<RunPhaseTimeListObject> runPTLInListForPainting)
+	{
+		if(runPTLInListForPainting.Count > 0)
+		{
+			//get first TC start value
+			RunPhaseTimeListObject rptlfp = (RunPhaseTimeListObject) runPTLInListForPainting[0];
+			double firstValue = rptlfp.tcStart;
+
+			if(firstValue < 0)
+				return Math.Abs(firstValue);
+		}
+
+		return 0;
+	}
+
+	double getRunSRunITimeTotalWithExtraPTLTime (double timeTotal, List<RunPhaseTimeListObject> runPTLInListForPainting, double negativePTLTime)
+	{
+		double timeTotalWithExtraPTL = timeTotal;
+		if(runPTLInListForPainting.Count > 0)
+		{
+			//get last TC end value
+			RunPhaseTimeListObject rptlfp = (RunPhaseTimeListObject) runPTLInListForPainting[runPTLInListForPainting.Count -1];
+			timeTotalWithExtraPTL = rptlfp.tcEnd;
+		}
+
+		return timeTotalWithExtraPTL + negativePTLTime;
+	}
+
+	void paintRunSRunIContactChunks(Gdk.Pixmap pixmap, int alto, int ancho, int bottomMargin,
+			List<RunPhaseTimeListObject> runPTLInListForPainting,
+			double timeTotal, double timeTotalWithExtraPTL, double negativePTLTime,
+			bool drawStartEnd)
+	{
+		int lastChunkStart = 0;
+		int chunkMargins = 4;
+
+		LogB.Information("CONTACT CHUNKS");
+		foreach (RunPhaseTimeListObject inPTL in runPTLInListForPainting)
+		{
+			LogB.Information("inPTL: " + inPTL.ToString());
+			int xStart = event_execute_rightMargin + Convert.ToInt32((ancho - 2*event_execute_rightMargin) *
+					(inPTL.tcStart + negativePTLTime) / timeTotalWithExtraPTL);
+
+			int xEnd = event_execute_rightMargin + Convert.ToInt32((ancho - 2*event_execute_rightMargin) *
+					(inPTL.tcEnd + negativePTLTime) / timeTotalWithExtraPTL);
+
+			pixmap.DrawRectangle(pen_gris, true,
+					new Rectangle (xStart, alto-bottomMargin-4, xEnd-xStart, 4));
+
+			//manage chunks indications
+			if(inPTL.phase == RunPhaseTimeListObject.Phases.START)
+			{
+				//draw the vertical start line
+				pixmap.DrawLine(pen_gris,
+						xStart - chunkMargins, alto-bottomMargin -4,
+						xStart - chunkMargins, alto-bottomMargin -(4 + chunkMargins));
+				lastChunkStart = xStart;
+			}
+			else if(inPTL.phase == RunPhaseTimeListObject.Phases.END)
+			{
+				//draw the vertical end line
+				pixmap.DrawLine(pen_gris,
+						xEnd + chunkMargins, alto-bottomMargin -4,
+						xEnd + chunkMargins, alto-bottomMargin -(4 + chunkMargins));
+
+				//draw the horizontal start-end line
+				pixmap.DrawLine(pen_gris,
+						lastChunkStart - chunkMargins, alto-bottomMargin -(4 + chunkMargins),
+						xEnd + chunkMargins, alto-bottomMargin -(4 + chunkMargins));
+			}
+
+		}
+
+		if(! drawStartEnd)
+			return;
+
+		//paint start vertical line (only on run simple)
+		int xStart2 = event_execute_rightMargin + Convert.ToInt32((ancho - 2*event_execute_rightMargin) *
+				(negativePTLTime) / timeTotalWithExtraPTL) -1;
+		pixmap.DrawLine(pen_azul, xStart2, 10, xStart2, 20);
+
+		int lWidth = 1;
+		int lHeight = 1;
+		layoutMid_run_simple.SetMarkup("Start");
+		layoutMid_run_simple.GetPixelSize(out lWidth, out lHeight);
+		event_execute_run_simple_double_contacts_pixmap.DrawLayout (pen_azul,
+				xStart2 -lWidth/2, 0 - lHeight/4, layoutMid_run_simple);
+
+		//paint end vertical line (only on run simple)
+		int xEnd2 = event_execute_rightMargin + Convert.ToInt32((ancho - 2*event_execute_rightMargin) *
+				(timeTotal + negativePTLTime) / timeTotalWithExtraPTL);
+		pixmap.DrawLine(pen_azul, xEnd2, 10, xEnd2, 20);
+
+		layoutMid_run_simple.SetMarkup("End");
+		layoutMid_run_simple.GetPixelSize(out lWidth, out lHeight);
+		event_execute_run_simple_double_contacts_pixmap.DrawLayout (pen_azul,
+				xEnd2 -lWidth/2, 0 - lHeight/4, layoutMid_run_simple);
+	}
+
 	private void paintRunInterval (Gtk.DrawingArea drawingarea, double distance, double distanceTotal, string distancesString, 
 			double lastTime, string timesString, double avgTime, 
 			double maxValue, double minValue, int tracks, int topMargin, int bottomMargin, 
 			int hightValuePosition, int lowValuePosition, bool startIn,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
-			RepetitiveConditionsWindow repetitiveConditionsWin)
+			RepetitiveConditionsWindow repetitiveConditionsWin, RunPhaseTimeList runPTL)
 	{
 		//int topMargin = 10; 
 		int ancho=drawingarea.Allocation.Width;
@@ -1465,8 +1657,10 @@ public partial class ChronoJumpWindow
 			*/
 
 			//paint reference guide black and green if needed
-			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
-			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide,
+					alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide,
+					alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 
 			string [] myTimesStringFull = timesString.Split(new char[] {'='});
 			int count = 0;
@@ -1478,8 +1672,28 @@ public partial class ChronoJumpWindow
 			Gdk.GC myPen = pen_rojo; //default value
 			double myValue = 0;
 
+			// start of contact chunks
+			double negativePTLTime = 0;
+			double timeTotalWithExtraPTL = timeTotal;
+			if(runPTL != null)
+			{
+				List<RunPhaseTimeListObject> runPTLInListForPainting = runPTL.InListForPainting();
+
+				negativePTLTime = getRunSRunINegativePTLTime(runPTLInListForPainting);
+				timeTotalWithExtraPTL = getRunSRunITimeTotalWithExtraPTLTime (timeTotal, runPTLInListForPainting, negativePTLTime);
+
+				LogB.Information(string.Format("timeTotal: {0}, negativePTLTime: {1}, timeTotalWithExtraPTL: {2}",
+							timeTotal, negativePTLTime, timeTotalWithExtraPTL));
+
+
+				paintRunSRunIContactChunks(event_execute_pixmap, alto, ancho, bottomMargin,
+						runPTLInListForPainting, timeTotal, timeTotalWithExtraPTL, negativePTLTime, false);
+			}
+			// end of contact chunks
+
 			foreach (string myTime in myTimesStringFull) 
 			{
+				LogB.Information(myTime.ToString());
 				myTimeDouble = Convert.ToDouble(myTime);
 				if(myTimeDouble < 0)
 					myTimeDouble = 0;
@@ -1497,14 +1711,35 @@ public partial class ChronoJumpWindow
 				myValue = myDistance / myTimeDouble;
 
 				int xStart = event_execute_rightMargin;
-				if(myTimeDoubleAccumulated - myTimeDouble > 0)
+				if(myTimeDoubleAccumulated - myTimeDouble > 0 || negativePTLTime > 0)
 					xStart = event_execute_rightMargin + Convert.ToInt32((ancho - 2*event_execute_rightMargin) * 
-							((myTimeDoubleAccumulated - myTimeDouble) / timeTotal));
+							(myTimeDoubleAccumulated + negativePTLTime - myTimeDouble) / timeTotalWithExtraPTL);
 
 				int xEnd = event_execute_rightMargin;
 				if(myTimeDoubleAccumulated > 0)
 					xEnd = event_execute_rightMargin + Convert.ToInt32((ancho - 2*event_execute_rightMargin) * 
-							(myTimeDoubleAccumulated / timeTotal));
+							(myTimeDoubleAccumulated + negativePTLTime) / timeTotalWithExtraPTL);
+
+				/*
+				LogB.Information(string.Format("ancho: {0}, (ancho - 2*event_execute_rightMargin): {1}, timeTotal: {2}, timeTotalWithExtraPTL: {3}",
+							ancho, (ancho - 2*event_execute_rightMargin), timeTotal, timeTotalWithExtraPTL ));
+
+				LogB.Information(string.Format("xStart: {0}, b: {1}, c: {2}, num: {3}, numDenom: {4}, numDenom*anchoright: {5}, xStartCalc: {6}, xStart: {7}",
+							myTimeDoubleAccumulated, negativePTLTime, myTimeDouble,
+							(myTimeDoubleAccumulated + negativePTLTime - myTimeDouble),
+							(myTimeDoubleAccumulated + negativePTLTime - myTimeDouble) / timeTotalWithExtraPTL,
+							Convert.ToInt32((ancho - 2*event_execute_rightMargin) * (myTimeDoubleAccumulated + negativePTLTime) / timeTotalWithExtraPTL),
+							event_execute_rightMargin + Convert.ToInt32((ancho - 2*event_execute_rightMargin) *
+							(myTimeDoubleAccumulated + negativePTLTime - myTimeDouble) / timeTotalWithExtraPTL),
+							xStart
+							));
+				LogB.Information(string.Format("xEnd: {0}, b: {1}, num: {2}, numDenom: {3}, xEnd: {4}",
+							myTimeDoubleAccumulated, negativePTLTime,
+							(myTimeDoubleAccumulated + negativePTLTime),
+							(myTimeDoubleAccumulated + negativePTLTime) / timeTotalWithExtraPTL,
+							xEnd
+							));
+				*/
 
 				//LogB.Information("xStart: " + xStart.ToString() + "; xEnd: " + xEnd);
 
@@ -1971,7 +2206,9 @@ public partial class ChronoJumpWindow
 				break;
 			case EventType.Types.RUN:
 				if(thisRunIsSimple)
-					PrepareRunSimpleGraph(currentEventExecute.PrepareEventGraphRunSimpleObject, animate);
+					PrepareRunSimpleGraph(currentEventExecute.PrepareEventGraphRunSimpleObject, animate,
+							currentEventExecute.RunPTL
+							);
 				else {
 					bool volumeOnHere = preferences.volumeOn;
 					//do not play good or bad sounds at RSA because we need to hear the GO sound
@@ -1979,13 +2216,17 @@ public partial class ChronoJumpWindow
 						volumeOnHere = false;
 
 					PrepareRunIntervalGraph(
+							//TODO: pass most of this as (including RunPTL)
+							//new PrepareEventGraphRunIntervalObject(distance, lastTime, ...)
 							currentEventExecute.PrepareEventGraphRunIntervalObject.distance, 
 							currentEventExecute.PrepareEventGraphRunIntervalObject.lastTime,
 							currentEventExecute.PrepareEventGraphRunIntervalObject.timesString,
 							currentEventExecute.PrepareEventGraphRunIntervalObject.distanceTotal,
 							currentEventExecute.PrepareEventGraphRunIntervalObject.distancesString,
 							currentEventExecute.PrepareEventGraphRunIntervalObject.startIn,
-							volumeOnHere, preferences.gstreamer, repetitiveConditionsWin);
+							volumeOnHere, preferences.gstreamer, repetitiveConditionsWin,
+							currentEventExecute.RunPTL
+							);
 				}
 				break;
 			case EventType.Types.REACTIONTIME:
