@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2017-2018   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -77,15 +77,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.DrawingArea force_capture_drawingarea;
 	Gdk.Pixmap force_capture_pixmap = null;
 
-	//analyze tab
-	[Widget] Gtk.Button button_force_sensor_analyze_load;
-	[Widget] Gtk.Label label_force_sensor_analyze;
-	[Widget] Gtk.Image image_force_sensor_graph;
-	[Widget] Gtk.Viewport viewport_force_sensor_graph;
-	[Widget] Gtk.Button button_force_sensor_image_save_rfd;
-
-	[Widget] Gtk.SpinButton spin_force_duration_seconds;
-	[Widget] Gtk.RadioButton radio_force_duration_seconds;
 
 	Thread forceCaptureThread;
 	static bool forceProcessFinish;
@@ -98,6 +89,7 @@ public partial class ChronoJumpWindow
 	static bool forceSensorOtherMessageShowSeconds;
 	static DateTime forceSensorTimeStart;
 	static string lastForceSensorFile = "";
+	static string lastForceSensorFullPath = "";
 
 	int usbDisconnectedCount;
 	int usbDisconnectedLastTime;
@@ -293,7 +285,6 @@ public partial class ChronoJumpWindow
 		}
 
 		capturingForce = forceStatus.STOP;
-		forceSensorButtonsSensitive(false);
 		forceSensorTimeStart = DateTime.Now;
 		forceSensorOtherMessageShowSeconds = true;
 
@@ -312,10 +303,12 @@ public partial class ChronoJumpWindow
 		}
 		else if (o == (object) button_execute_test)
 		{
+			forceSensorButtonsSensitive(false);
 			forceSensorOtherMode = forceSensorOtherModeEnum.CAPTURE_PRE;
 			forceOtherThread = new Thread(new ThreadStart(forceSensorCapturePre));
 		}
 		else { //if (o == (object) button_check_version)
+			forceSensorButtonsSensitive(false);
 			forceSensorOtherMode = forceSensorOtherModeEnum.CHECK_VERSION;
 			forceOtherThread = new Thread(new ThreadStart(forceSensorCheckVersionPre));
 		}
@@ -361,10 +354,10 @@ public partial class ChronoJumpWindow
 			event_execute_label_message.Text = forceSensorOtherMessage;
 			LogB.ThreadEnding();
 
-			if(
-					forceSensorOtherMode == forceSensorOtherModeEnum.TARE ||
-					forceSensorOtherMode == forceSensorOtherModeEnum.CALIBRATE ||
-					forceSensorOtherMode == forceSensorOtherModeEnum.CHECK_VERSION)
+			if(forceSensorOtherMode == forceSensorOtherModeEnum.TARE ||
+				forceSensorOtherMode == forceSensorOtherModeEnum.CALIBRATE)
+				return false;
+			else if(forceSensorOtherMode == forceSensorOtherModeEnum.CHECK_VERSION)
 				forceSensorButtonsSensitive(true);
 			else //if(forceSensorOtherMode == forceSensorOtherModeEnum.CAPTURE_PRE)
 				forceSensorCapturePre2();
@@ -518,6 +511,7 @@ public partial class ChronoJumpWindow
 		event_execute_button_finish.Sensitive = true;
 		event_execute_button_cancel.Sensitive = true;
 		button_force_sensor_image_save_signal.Sensitive = false;
+		button_force_sensor_analyze_recalculate.Sensitive = false;
 		forceCaptureStartMark = false;
 		//vscale_force_sensor.Value = 0;
 		label_force_sensor_value_max.Text = "0";
@@ -683,6 +677,7 @@ public partial class ChronoJumpWindow
 		else {
 			//call graph
 			File.Copy(fileName, UtilEncoder.GetmifCSVFileName(), true); //can be overwritten
+			lastForceSensorFullPath = fileName;
 			capturingForce = forceStatus.COPIED_TO_TMP;
 		}
 	}
@@ -726,6 +721,7 @@ LogB.Information(" fc C ");
 
 				button_force_sensor_image_save_signal.Sensitive = false;
 				button_force_sensor_image_save_rfd.Sensitive = false;
+				button_force_sensor_analyze_recalculate.Sensitive = false;
 			}
 			else
 				event_execute_label_message.Text = "";
@@ -745,6 +741,7 @@ LogB.Information(" fc D ");
 
 			forceSensorButtonsSensitive(true);
 			button_force_sensor_image_save_signal.Sensitive = true;
+			button_force_sensor_analyze_recalculate.Sensitive = true;
 
 			//finish, cancel: sensitive = false
 			hideButtons();
@@ -971,7 +968,6 @@ LogB.Information(" fc R ");
 		force_capture_allocationXOld = allocation.Width;
 	}
 
-
 	private void on_button_force_sensor_load_clicked (object o, EventArgs args)
 	{
 		if (currentSession == null)
@@ -991,14 +987,34 @@ LogB.Information(" fc R ");
 		if (filechooser.Run () == (int)ResponseType.Accept)
 		{
 			lastForceSensorFile = Util.RemoveExtension(Util.GetLastPartOfPath(filechooser.Filename));
-			File.Copy(filechooser.Filename, UtilEncoder.GetmifCSVFileName(), true); //can be overwritten
+			lastForceSensorFullPath = filechooser.Filename; //used on recalculate
 
-			forceSensorDoSignalGraph();
-			forceSensorDoRFDGraph();
+			forceSensorCopyTempAndDoGraphs();
 		}
 		filechooser.Destroy ();
 	}
 
+	private void on_button_force_sensor_analyze_recalculate_clicked (object o, EventArgs args)
+	{
+		if(! Util.FileExists(lastForceSensorFullPath))
+		{
+			new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFound);
+			return;
+		}
+
+		if(lastForceSensorFullPath != null && lastForceSensorFullPath != "")
+			forceSensorCopyTempAndDoGraphs();
+	}
+
+	private void forceSensorCopyTempAndDoGraphs()
+	{
+		File.Copy(lastForceSensorFullPath, UtilEncoder.GetmifCSVFileName(), true); //can be overwritten
+
+		forceSensorDoSignalGraph();
+		forceSensorDoRFDGraph();
+	}
+
+
 	void forceSensorDoRFDGraph()
 	{
 		string imagePath = UtilEncoder.GetmifTempFileName();
@@ -1132,6 +1148,7 @@ LogB.Information(" fc R ");
 		label_force_sensor_value_max.Text = forceSensorValues.ForceMax.ToString();
 		label_force_sensor_value_min.Text = forceSensorValues.ForceMin.ToString();
 		button_force_sensor_image_save_signal.Sensitive = true;
+		button_force_sensor_analyze_recalculate.Sensitive = true;
 	}
 
 	private void forcePaintHVLines(double maxForce, double minForce, int lastTime)
@@ -1293,7 +1310,7 @@ LogB.Information(" fc R ");
 	private void showHideForceSensorControls(bool modeForceSensor)
 	{
 		hbox_capture_phases_time_record.Visible = ! modeForceSensor;
-		hbox_options_top.Visible = ! modeForceSensor;
+		button_image_test_zoom.Visible = ! modeForceSensor;
 		notebook_options_top.Visible = ! modeForceSensor;
 
 		button_threshold.Visible = ! modeForceSensor;
@@ -1302,25 +1319,56 @@ LogB.Information(" fc R ");
 		menuitem_force_sensor_check_version.Visible = modeForceSensor;
 	}
 
+	private void on_button_force_sensor_adjust_clicked (object o, EventArgs args)
+	{
+		notebook_options_top.Visible = true;
+		notebook_options_at_execute_button.CurrentPage = 2;
+		forceSensorCaptureAdjustSensitivity(false);
+		//event_execute_label_message.Text = Catalog.GetString("If you want to calibrate, please tare first.");
+		event_execute_label_message.Text = "If you want to calibrate, please tare first.";
+	}
+	private void on_button_force_sensor_adjust_close_clicked (object o, EventArgs args)
+	{
+		notebook_options_top.Visible = false;
+		notebook_options_at_execute_button.CurrentPage = 0;
+		forceSensorCaptureAdjustSensitivity(true);
+	}
+
+	private void forceSensorCaptureAdjustSensitivity(bool s) //s for sensitive. When adjusting s = false
+	{
+		hbox_force_buttons.Sensitive = s;
+
+		button_activate_chronopics.Sensitive = s;
+		image_test.Sensitive = s;
+		button_execute_test.Sensitive = s;
+		button_force_sensor_image_save_signal.Sensitive = s;
+
+		main_menu.Sensitive = s;
+		notebook_session_person.Sensitive = s;
+		hbox_contacts_sup_capture_analyze_two_buttons.Sensitive = s;
+		hbox_top_person.Sensitive = s;
+	}
+
 	private void on_button_force_sensor_adjust_help_clicked (object o, EventArgs args)
 	{
-		new DialogMessage("Force sensor adjust data", Constants.MessageTypes.INFO, preferences.GetForceSensorAdjustString());
+		new DialogMessage("Force sensor adjust data", Constants.MessageTypes.INFO,
+				preferences.GetForceSensorAdjustString());
 	}
 
 	double lastChangedTime; //changeSlideCode
 	private void changeSlideIfNeeded(int time, double force)
 	{
-		if(force > 100) {
+		if(force > 75) {
 			//changeSlide if one second or more elapsed since last change
-			if(time - lastChangedTime >= 1)
+			if(time - lastChangedTime >= 1000000)
 			{
 				changeSlide(true);
 				lastChangedTime = time;
 			}
 		}
-		if(force < -100) {
+		if(force < -75) {
 			//changeSlide if one second or more elapsed since last change
-			if(time - lastChangedTime >= 1)
+			if(time - lastChangedTime >= 1000000)
 			{
 				changeSlide(false);
 				lastChangedTime = time;
