@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -28,10 +28,7 @@ using Mono.Unix;
 public class HelpPorts
 {
 	[Widget] Gtk.Dialog dialog_help_ports;
-	[Widget] Gtk.TextView textview_info;
-	[Widget] Gtk.TextView textview_detected;
 	[Widget] Gtk.Label label_info;
-	[Widget] Gtk.Label label_detection;
 	[Widget] Gtk.Label label_detected;
 	[Widget] Gtk.Label label_help_info;
 	[Widget] Gtk.Label label_help_manual;
@@ -41,7 +38,7 @@ public class HelpPorts
 	public HelpPorts ()
 	{
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "dialog_help_ports", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "dialog_help_ports.glade", "dialog_help_ports", "chronojump");
 		gladeXML.Autoconnect(this);
 
 		//put an icon to window
