@@ -40,11 +40,13 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Alignment alignment_encoder_capture_options;
 			
 	//RFID
-	[Widget] Gtk.Label label_rfid_contacts;
-	[Widget] Gtk.Label label_rfid_encoder;
+	[Widget] Gtk.Label label_rfid_wait;
+	[Widget] Gtk.Label label_rfid_encoder_wait;
+
+	[Widget] Gtk.Label label_logout_seconds;
+	[Widget] Gtk.Label label_logout_seconds_encoder;
 	
 	//better raspberry controls
-	[Widget] Gtk.Entry entry_raspberry_extra_weight;
 	[Widget] Gtk.Box hbox_encoder_capture_extra_mass_no_raspberry;
 	[Widget] Gtk.Box hbox_encoder_capture_extra_mass_raspberry;
 	[Widget] Gtk.HBox hbox_encoder_im_weights_n;
@@ -93,13 +95,19 @@ public partial class ChronoJumpWindow
 	private static bool shouldUpdateRFIDGui;
 	private static bool shouldShowRFIDDisconnected;
 	private static bool updatingRFIDGuiStuff;
+	private static bool networksRunIntervalCanChangePersonSQLReady;
+	private static DateTime startedRFIDWait;
 	private bool rfidProcessCancel;
 	private bool rfidIsDifferent;
-	private DateTime currentPersonCompujumpLoginTime;
+	//private bool compujumpAutologout;
+	//private static CompujumpAutologout compujumpAutologout;
+	private CompujumpAutologout compujumpAutologout;
 
 	DialogPersonPopup dialogPersonPopup;
 		
 	Config configChronojump;
+	bool maximizeWindowAtStartDone = false;
+
 	private void configInitRead()
 	{
 		configChronojump.Read();
@@ -120,6 +128,9 @@ public partial class ChronoJumpWindow
 			//button_encoder_person_change.Visible = false;
 			//TODO: don't allow edit person on person treeview
 
+			//don't allow to change persons view options
+			view_menuitem.Visible = false;
+
 			//dont't show persons_bottom hbox where users can be edited, deleted if persons at lateral is selected on preferences
 			vbox_persons_bottom.Visible = false;
 
@@ -160,6 +171,7 @@ public partial class ChronoJumpWindow
 			updatingRFIDGuiStuff = false;
 			shouldUpdateRFIDGui = false;
 			rfidProcessCancel = false;
+			networksRunIntervalCanChangePersonSQLReady = true;
 
 			chronopicRegisterUpdate(false);
 			if(chronopicRegister != null && chronopicRegister.GetRfidPortName() != "")
@@ -183,6 +195,8 @@ public partial class ChronoJumpWindow
 	{
 		LogB.Information("RFID Start");
 		rfid.Start();
+		startedRFIDWait = DateTime.MinValue;
+		LogB.Information("networksRI: " + networksRunIntervalCanChangePersonSQLReady.ToString());
 		//rfid.ChangedEvent += new EventHandler(this.rfidChanged);
 	}
 	private void rfidChanged(object sender, EventArgs e)
@@ -194,9 +208,16 @@ public partial class ChronoJumpWindow
 		{
 			LogB.Information("RFID changed to: " + rfid.Captured);
 
-			capturedRFID = rfid.Captured;
-			rfidIsDifferent = true;
-			shouldUpdateRFIDGui = true;
+			if(isCompujumpCapturing ())
+			{
+				startedRFIDWait = DateTime.Now;
+				LogB.Information("... but we are on the middle of capture");
+			} else {
+				capturedRFID = rfid.Captured;
+				rfidIsDifferent = true;
+
+				shouldUpdateRFIDGui = true;
+			}
 		}
 	}
 
@@ -204,8 +225,14 @@ public partial class ChronoJumpWindow
 	{
 		if(currentSession != null && rfid.Captured == capturedRFID)
 		{
-			rfidIsDifferent = false;
-			shouldUpdateRFIDGui = true;
+			if(isCompujumpCapturing ())
+			{
+				startedRFIDWait = DateTime.Now;
+				LogB.Information("... but we are on the middle of capture");
+			} else {
+				rfidIsDifferent = false;
+				shouldUpdateRFIDGui = true;
+			}
 		}
 	}
 
@@ -217,7 +244,8 @@ public partial class ChronoJumpWindow
 
 	private void configInitFromPreferences()
 	{
-		configChronojump = new Config();
+		if(configChronojump == null)
+			configChronojump = new Config();
 
 		configChronojump.Maximized = preferences.maximized;
 		configChronojump.PersonWinHide = preferences.personWinHide;
@@ -229,7 +257,7 @@ public partial class ChronoJumpWindow
 
 	private void configDo()
 	{
-		LogB.Information("Config:\n" + configChronojump.ToString());
+		LogB.Information("Is Compujump?:\n" + configChronojump.Compujump.ToString());
 			
 		/*
 		 * TODO: do an else to any option
@@ -239,15 +267,20 @@ public partial class ChronoJumpWindow
 		 * But note this has to be executed only if it has changed!!
 		 */
 
-		if(configChronojump.Maximized == Preferences.MaximizedTypes.NO)
+		//only change maximizez status on start
+		if( ! maximizeWindowAtStartDone )
 		{
-			app1.Unmaximize();
-			app1.Decorated = true;
-			button_start_quit.Visible = false;
-		} else {
-			app1.Decorated = (configChronojump.Maximized != Preferences.MaximizedTypes.YESUNDECORATED);
-			app1.Maximize();
-			button_start_quit.Visible = ! app1.Decorated;
+			if(configChronojump.Maximized == Preferences.MaximizedTypes.NO)
+			{
+				app1.Unmaximize();
+				app1.Decorated = true;
+				button_start_quit.Visible = false;
+			} else {
+				app1.Decorated = (configChronojump.Maximized != Preferences.MaximizedTypes.YESUNDECORATED);
+				app1.Maximize();
+				button_start_quit.Visible = ! app1.Decorated;
+			}
+			maximizeWindowAtStartDone = true;
 		}
 
 		if(configChronojump.CustomButtons)
@@ -414,10 +447,8 @@ public partial class ChronoJumpWindow
 		}
 		*/
 
-		//label_rfid_contacts.Visible = (UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX);
-		//label_rfid_encoder.Visible = (UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX);
-		label_rfid_contacts.Visible = false;
-		label_rfid_encoder.Visible = false;
+		label_rfid_wait.Visible = false;
+		label_rfid_encoder_wait.Visible = false;
 	}
 
 	DialogMessage dialogMessageNotAtServer;
@@ -433,11 +464,33 @@ public partial class ChronoJumpWindow
 
 		if(! threadRFID.IsAlive || rfidProcessCancel)
 		{
+			label_rfid_wait.Visible = false;
+			label_rfid_encoder_wait.Visible = false;
+
 			LogB.ThreadEnding();
 			LogB.ThreadEnded();
 			return false;
 		}
 
+		/*
+		 * if we are on the middle of an encoderCapture, just show a wait message
+		 * to avoid problems of SQL on encoder capture stuff and on person login stuff
+		 */
+		TimeSpan span = DateTime.Now - startedRFIDWait;
+		if(span.TotalSeconds < 2) {
+			label_rfid_wait.Visible = true;
+			label_rfid_encoder_wait.Visible = true;
+		} else {
+			label_rfid_wait.Visible = false;
+			label_rfid_encoder_wait.Visible = false;
+		}
+
+		if(isCompujumpCapturing ())
+			return true;
+
+		//---- end of checking if we are on the middle of capture.
+
+
 		//don't allow this method to be called again until ended
 		//Note RFID detection can send many cards (the same) per second
 		if(updatingRFIDGuiStuff)
@@ -449,9 +502,9 @@ public partial class ChronoJumpWindow
 		shouldUpdateRFIDGui = false;
 		updatingRFIDGuiStuff = true;
 
-		//TODO: this pulseRFID need only the GTK stuff, not the rest
-		label_rfid_contacts.Text = capturedRFID; //GTK
-		label_rfid_encoder.Text = capturedRFID; //GTK
+		//is we are on analyze, switch to capture
+		if(! radio_mode_encoder_capture_small.Active)
+			radio_mode_encoder_capture_small.Active = true;
 
 		/*
 		 * This method is shown on diagrams/processes/rfid-local-read.dia
@@ -508,14 +561,13 @@ public partial class ChronoJumpWindow
 					SqlitePerson.Update(pLocal);
 				}
 
-				currentPersonCompujumpLoginTime = DateTime.Now;
 				currentPerson = pLocal;
 				insertAndAssignPersonSessionIfNeeded(json);
 
 				if(json.LastPersonWasInserted)
 				{
 					string imageFile = json.LastPersonByRFIDImageURL;
-					if(imageFile != "")
+					if(imageFile != null && imageFile != "")
 					{
 						string image_dest = Util.GetPhotoFileName(false, currentPerson.UniqueID);
 						if(UtilMultimedia.GetImageType(imageFile) == UtilMultimedia.ImageTypes.PNG)
@@ -541,7 +593,6 @@ public partial class ChronoJumpWindow
 			LogB.Information("RFID person exists locally!!");
 			if(rfidIsDifferent || dialogPersonPopup == null || ! dialogPersonPopup.Visible)
 			{
-				currentPersonCompujumpLoginTime = DateTime.Now;
 				currentPerson = pLocal;
 				insertAndAssignPersonSessionIfNeeded(json);
 
@@ -551,11 +602,48 @@ public partial class ChronoJumpWindow
 			}
 		}
 
+		//----- Start upload temp tests
+		//select UploadTemp tests (have not been uploaded by network errors)
+
+		Sqlite.Open(); // ---------------->
+
+		List<UploadEncoderDataFullObject> listEncoderTemp = SqliteJson.SelectTempEncoder(true);
+		List<UploadSprintDataObject> listSprintTemp = SqliteJson.SelectTempSprint(true);
+
+		//Upload them
+		if(listEncoderTemp.Count > 0)
+		{
+			foreach(UploadEncoderDataFullObject uedfo in listEncoderTemp)
+			{
+				bool success = json.UploadEncoderData(uedfo);
+				LogB.Information(json.ResultMessage);
+				if(success)
+					SqliteJson.DeleteTempEncoder(true, uedfo.uniqueId); //delete the record
+			}
+		}
+		if(listSprintTemp.Count > 0)
+		{
+			foreach(UploadSprintDataObject usdo in listSprintTemp)
+			{
+				bool success = json.UploadSprintData(usdo);
+				LogB.Information(json.ResultMessage);
+				if(success)
+					SqliteJson.DeleteTempSprint(true, usdo.uniqueId); //delete the record
+			}
+		}
+
+		Sqlite.Close(); // <----------------
+
+		//----- End upload temp tests
+
+
 		if(currentPerson != null && currentPersonWasNull)
 			sensitiveGuiYesPerson();
 
 		if(pChangedShowTasks)
 		{
+			compujumpAutologout = new CompujumpAutologout();
+
 			/*TODO:
 			int rowToSelect = myTreeViewPersons.FindRow(currentPerson.UniqueID);
 			if(rowToSelect != -1)
@@ -595,6 +683,10 @@ public partial class ChronoJumpWindow
 		if(currentPerson == null)
 			return;
 
+		//update login time
+		if(compujumpAutologout != null)
+			compujumpAutologout.UpdateLoginTime();
+
 		getTasksExercisesAndPopup();
 	}
 
@@ -647,13 +739,17 @@ public partial class ChronoJumpWindow
 			dialogMessageNotAtServer.on_close_button_clicked(new object(), new EventArgs());
 
 		dialogPersonPopup = new DialogPersonPopup(
-				currentPerson.UniqueID, currentPerson.Name, capturedRFID, tasks, stationsCount, serverConnected);
+				currentPerson.UniqueID, currentPerson.Name, capturedRFID, tasks, stationsCount,
+				serverConnected, compujumpAutologout.Active);
 
 		dialogPersonPopup.Fake_button_start_task.Clicked -= new EventHandler(compujumpTaskStart);
 		dialogPersonPopup.Fake_button_start_task.Clicked += new EventHandler(compujumpTaskStart);
 
 		dialogPersonPopup.Fake_button_person_logout.Clicked -= new EventHandler(compujumpPersonLogout);
 		dialogPersonPopup.Fake_button_person_logout.Clicked += new EventHandler(compujumpPersonLogout);
+
+		dialogPersonPopup.Fake_button_person_autologout_changed.Clicked -= new EventHandler(compujumpPersonAutoLogoutChanged);
+		dialogPersonPopup.Fake_button_person_autologout_changed.Clicked += new EventHandler(compujumpPersonAutoLogoutChanged);
 	}
 
 	private void compujumpTaskStart(object o, EventArgs args)
@@ -717,7 +813,7 @@ public partial class ChronoJumpWindow
 
 		Pixbuf pixbuf;
 		if(task.Load > 0)
-			entry_raspberry_extra_weight.Text = Convert.ToInt32(task.Load).ToString();
+			spin_encoder_extra_weight.Value = Convert.ToDouble(task.Load);
 
 		if(task.Speed > 0) {
 			repetitiveConditionsWin.EncoderMeanSpeedHigherValue = task.Speed;
@@ -756,6 +852,20 @@ public partial class ChronoJumpWindow
 		sensitiveGuiNoPerson ();
 	}
 
+	private void compujumpPersonAutoLogoutChanged(object o, EventArgs args)
+	{
+		compujumpAutologout.Active = dialogPersonPopup.Autologout;
+	}
+
+	//are we capturing runInterval or encoder?
+	private bool isCompujumpCapturing ()
+	{
+		if(compujumpAutologout == null)
+			return false;
+
+		return(compujumpAutologout.IsCompujumpCapturing());
+	}
+
 	/*
 	 *
 	 * This code uses a watcher to see changes on a filename
@@ -877,4 +987,184 @@ public partial class ChronoJumpWindow
 		}
 	}
 	*/
+
+}
+
+//Class for manage autologout on Compujump
+//TODO: expand this class to manage better resttime and clearer
+public class CompujumpAutologout
+{
+	public bool Active;
+	public DateTime lastEncoderAnalyzeTime;
+
+	private bool capturingRunInterval;
+	private bool capturingEncoder;
+
+	private DateTime loginTime;
+	private DateTime lastRunIntervalTime;
+	private DateTime lastEncoderCaptureTime;
+	private int logoutMinutes = 3;
+
+	public CompujumpAutologout ()
+	{
+		Active = true;
+		loginTime = DateTime.Now;
+
+		capturingRunInterval = false;
+		capturingEncoder = false;
+
+		lastRunIntervalTime = DateTime.MinValue;
+		lastEncoderCaptureTime = DateTime.MinValue;
+		lastEncoderAnalyzeTime = DateTime.MinValue;
+	}
+
+	public void UpdateLoginTime()
+	{
+		loginTime = DateTime.Now;
+	}
+
+	public void StartCapturingRunInterval()
+	{
+		capturingRunInterval = true;
+	}
+	public void EndCapturingRunInterval()
+	{
+		capturingRunInterval = false;
+		lastRunIntervalTime = DateTime.Now;
+	}
+
+	public void StartCapturingEncoder()
+	{
+		capturingEncoder = true;
+	}
+	public void EndCapturingEncoder()
+	{
+		capturingEncoder = false;
+		lastEncoderCaptureTime = DateTime.Now;
+	}
+
+	public void UpdateLastEncoderAnalyzeTime()
+	{
+		lastEncoderAnalyzeTime = DateTime.Now;
+	}
+
+	public bool IsCompujumpCapturing()
+	{
+		return (capturingRunInterval || capturingEncoder);
+	}
+
+	//mSinceLogin: time in 'm'inutes since login
+	private double mSinceLogin()
+	{
+		return DateTime.Now.Subtract(loginTime).TotalMinutes;
+	}
+	private double mSinceRunInterval()
+	{
+		return DateTime.Now.Subtract(lastRunIntervalTime).TotalMinutes;
+	}
+	private double mSinceEncoderCapture()
+	{
+		return DateTime.Now.Subtract(lastEncoderCaptureTime).TotalMinutes;
+	}
+	private double mSinceEncoderAnalyze()
+	{
+		return DateTime.Now.Subtract(lastEncoderAnalyzeTime).TotalMinutes;
+	}
+
+	//decide if use has to be autologout now
+	public bool ShouldILogoutNow()
+			//bool moreThanThreeMinutesSinceLastCapture
+	{
+		if(IsCompujumpCapturing())
+			return false;
+
+		if(Active &&
+				mSinceLogin() >= logoutMinutes &&
+	//			moreThanThreeMinutesSinceLastCapture &&
+				mSinceRunInterval() >= logoutMinutes &&
+				mSinceEncoderCapture() >= logoutMinutes &&
+				mSinceEncoderAnalyze() >= logoutMinutes
+				)
+			return true;
+
+		return false;
+	}
+
+	private double sSinceLogin()
+	{
+		return DateTime.Now.Subtract(loginTime).TotalSeconds;
+	}
+	private double sSinceRunInterval()
+	{
+		return DateTime.Now.Subtract(lastRunIntervalTime).TotalSeconds;
+	}
+	private double sSinceEncoderCapture()
+	{
+		return DateTime.Now.Subtract(lastEncoderCaptureTime).TotalSeconds;
+	}
+	private double sSinceEncoderAnalyze()
+	{
+		return DateTime.Now.Subtract(lastEncoderAnalyzeTime).TotalSeconds;
+	}
+	public int RemainingSeconds ()
+	{
+		int logoutDefaultS = logoutMinutes * 60;
+		double seconds = 0;
+
+		if(sSinceLogin() > seconds)
+			seconds = logoutDefaultS - sSinceLogin();
+
+		if(lastRunIntervalTime > DateTime.MinValue && logoutDefaultS - sSinceRunInterval() > seconds)
+			seconds = logoutDefaultS - sSinceRunInterval();
+
+		if(lastEncoderCaptureTime > DateTime.MinValue && logoutDefaultS - sSinceEncoderCapture() > seconds)
+			seconds = logoutDefaultS - sSinceEncoderCapture();
+
+		if(lastEncoderAnalyzeTime > DateTime.MinValue && logoutDefaultS - sSinceEncoderAnalyze() > seconds)
+			seconds = logoutDefaultS - sSinceEncoderAnalyze();
+
+		return Convert.ToInt32(seconds);
+	}
+
+	//showAll is for debug, user will see only one value
+	//TODO: separate between minutes and seconds and only display when remaining 10 seconds
+	public string RemainingSecondsOld(bool showAll)
+	{
+		if(! Active)
+			return "";
+
+		double elapsed = logoutMinutes - mSinceLogin();
+
+		string strAll = "Logout in (minutes): " + string.Format("login: {0}", Math.Round(elapsed, 2));
+		double maxTime = elapsed;
+
+		if(lastRunIntervalTime > DateTime.MinValue)
+		{
+			elapsed = logoutMinutes - mSinceRunInterval();
+			strAll += string.Format("; lastRunI: {0}", Math.Round(elapsed, 2));
+			if(elapsed > maxTime)
+			       maxTime = elapsed;
+		}
+
+		if(lastEncoderCaptureTime > DateTime.MinValue)
+		{
+			elapsed = logoutMinutes - mSinceEncoderCapture();
+			strAll += string.Format("; lastECapture {0}", Math.Round(elapsed, 2));
+			if(elapsed > maxTime)
+			       maxTime = elapsed;
+		}
+
+		if(lastEncoderAnalyzeTime > DateTime.MinValue)
+		{
+			elapsed = logoutMinutes - mSinceEncoderAnalyze();
+			strAll += string.Format("; lastEAnalyze: {0}", Math.Round(elapsed, 2));
+			if(elapsed > maxTime)
+			       maxTime = elapsed;
+		}
+
+		if(showAll)
+			return strAll;
+		else
+			return "Logout in\n" + Math.Round(maxTime, 2) + " min.";
+	}
 }
