@@ -206,6 +206,15 @@ public class PersonRecuperateWindow {
 		}
 	}
 
+	//if called from personRecuperateWindow
+	public virtual void HideAndNull()
+	{
+		if(PersonRecuperateWindowBox != null)
+			PersonRecuperateWindowBox.person_recuperate.Hide();
+
+		if(PersonRecuperateWindowBox != null)
+			PersonRecuperateWindowBox = null;
+	}
 	
 	protected virtual void on_button_close_clicked (object o, EventArgs args)
 	{
@@ -263,7 +272,7 @@ public class PersonRecuperateWindow {
 		}
 	}
 
-	public Button FakeButtonDone 
+	public Button FakeButtonDone
 	{
 		set { fakeButtonDone = value; }
 		get { return fakeButtonDone; }
@@ -613,6 +622,15 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		buttonRecuperateChangeSensitiveness();
 	}
 
+	public override void HideAndNull()
+	{
+		if(PersonsRecuperateFromOtherSessionWindowBox != null)
+			PersonsRecuperateFromOtherSessionWindowBox.person_recuperate.Hide();
+
+		if(PersonsRecuperateFromOtherSessionWindowBox != null)
+			PersonsRecuperateFromOtherSessionWindowBox = null;
+	}
+
 }
 
 
@@ -770,7 +788,7 @@ public class PersonNotUploadWindow : PersonsRecuperateFromOtherSessionWindow
 		on_button_close_clicked (o, new EventArgs());
 	}
 	
-	public new Button FakeButtonDone 
+	public new Button FakeButtonDone
 	{
 		set { fakeButtonDone = value; }
 		get { return fakeButtonDone; }
@@ -2491,24 +2509,29 @@ public class PersonAddMultipleWindow {
 }
 
 //show all events (jumps and runs) of a person in different sessions
-public class PersonShowAllEventsWindow {
+public class PersonShowAllEventsWindow
+{
 	
 	[Widget] Gtk.Window person_show_all_events;
-	
+
 	[Widget] Gtk.CheckButton checkbutton_only_current_session;
-	
-	TreeStore store;
+	[Widget] Gtk.Label label_person_name;
+
 	[Widget] Gtk.TreeView treeview_person_show_all_events;
 	[Widget] Gtk.Box hbox_combo_persons;
 	[Widget] Gtk.ComboBox combo_persons;
-	
+
+	public Gtk.Button fakeButtonDone;
+
+	TreeStore store;
 	static PersonShowAllEventsWindow PersonShowAllEventsWindowBox;
 
 	protected int sessionID;
 	
 	protected Person currentPerson;
 	
-	PersonShowAllEventsWindow (Gtk.Window parent, int sessionID, Person currentPerson) {
+	PersonShowAllEventsWindow (Gtk.Window parent, int sessionID, Person currentPerson)
+	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_show_all_events.glade", "person_show_all_events", "chronojump");
 		gladeXML.Autoconnect(this);
@@ -2519,7 +2542,10 @@ public class PersonShowAllEventsWindow {
 		person_show_all_events.Parent = parent;
 		this.sessionID = sessionID;
 		this.currentPerson = currentPerson;
-	
+
+		fakeButtonDone = new Gtk.Button();
+
+		label_person_name.Text = currentPerson.Name;
 		createComboPersons(sessionID, currentPerson.UniqueID.ToString(), currentPerson.Name);
 		createTreeView(treeview_person_show_all_events);
 		store = new TreeStore( typeof (string), typeof (string), typeof (string), typeof (string), 
@@ -2529,11 +2555,23 @@ public class PersonShowAllEventsWindow {
 		fillTreeView(treeview_person_show_all_events,store, currentPerson.UniqueID);
 	}
 	
-	static public PersonShowAllEventsWindow Show (Gtk.Window parent, int sessionID, Person currentPerson)
+	static public PersonShowAllEventsWindow Show (Gtk.Window parent, int sessionID, Person currentPerson, bool allowChangePerson)
 	{
 		if (PersonShowAllEventsWindowBox == null) {
 			PersonShowAllEventsWindowBox = new PersonShowAllEventsWindow (parent, sessionID, currentPerson);
 		}
+
+		if(allowChangePerson)
+		{
+			PersonShowAllEventsWindowBox.checkbutton_only_current_session.Visible = true;
+			PersonShowAllEventsWindowBox.hbox_combo_persons.Visible = true;
+			PersonShowAllEventsWindowBox.label_person_name.Visible = false;
+		} else {
+			PersonShowAllEventsWindowBox.checkbutton_only_current_session.Visible = false;
+			PersonShowAllEventsWindowBox.hbox_combo_persons.Visible = false;
+			PersonShowAllEventsWindowBox.label_person_name.Visible = true;
+		}
+
 		PersonShowAllEventsWindowBox.person_show_all_events.Show ();
 		
 		return PersonShowAllEventsWindowBox;
@@ -2617,17 +2655,23 @@ public class PersonShowAllEventsWindow {
 					myStr[6], myStr[7], myStr[8], myStr[9], myStr[10], myStr[11]);
 		}
 	}
-	
 
 	protected virtual void on_button_close_clicked (object o, EventArgs args)
 	{
+		fakeButtonDone.Click();
 		PersonShowAllEventsWindowBox.person_show_all_events.Hide();
 		PersonShowAllEventsWindowBox = null;
 	}
 	
 	protected virtual void on_delete_event (object o, DeleteEventArgs args)
 	{
+		fakeButtonDone.Click();
 		PersonShowAllEventsWindowBox.person_show_all_events.Hide();
 		PersonShowAllEventsWindowBox = null;
 	}
+
+	public Button FakeButtonDone
+	{
+		get { return fakeButtonDone; }
+	}
 }
