@@ -93,21 +93,13 @@ public class PreferencesWindow
 	[Widget] Gtk.Box vbox_runs_prevent_double_contact;
 	[Widget] Gtk.CheckButton checkbutton_runs_prevent_double_contact;
 	[Widget] Gtk.SpinButton spinbutton_runs_prevent_double_contact;
-	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_first;
-	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_average;
-	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_last;
 	[Widget] Gtk.Box vbox_runs_i_prevent_double_contact;
 	[Widget] Gtk.CheckButton checkbutton_runs_i_prevent_double_contact;
 	[Widget] Gtk.SpinButton spinbutton_runs_i_prevent_double_contact;
-	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_first;
-	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_average;
-	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_last;
 	
 	//encoder capture tab
 	[Widget] Gtk.SpinButton spin_encoder_capture_time;
 	[Widget] Gtk.SpinButton spin_encoder_capture_inactivity_end_time;
-	[Widget] Gtk.Box hbox_combo_main_variable;
-	[Widget] Gtk.ComboBox combo_main_variable;
 	[Widget] Gtk.Image image_encoder_gravitatory;
 	[Widget] Gtk.Image image_encoder_inertial;
 	[Widget] Gtk.Image image_encoder_triggers;
@@ -138,66 +130,13 @@ public class PreferencesWindow
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted2;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted3;
 
-	//force sensor tab
-	[Widget] Gtk.HBox hbox_force_1;
-	[Widget] Gtk.HBox hbox_force_2;
-	[Widget] Gtk.HBox hbox_force_3;
-	[Widget] Gtk.HBox hbox_force_4;
-	[Widget] Gtk.HBox hbox_force_impulse;
-	[Widget] Gtk.CheckButton check_force_1;
-	[Widget] Gtk.CheckButton check_force_2;
-	[Widget] Gtk.CheckButton check_force_3;
-	[Widget] Gtk.CheckButton check_force_4;
-	[Widget] Gtk.CheckButton check_force_impulse;
-	[Widget] Gtk.ComboBox combo_force_1_function;
-	[Widget] Gtk.ComboBox combo_force_2_function;
-	[Widget] Gtk.ComboBox combo_force_3_function;
-	[Widget] Gtk.ComboBox combo_force_4_function;
-	[Widget] Gtk.ComboBox combo_force_impulse_function;
-	[Widget] Gtk.ComboBox combo_force_1_type;
-	[Widget] Gtk.ComboBox combo_force_2_type;
-	[Widget] Gtk.ComboBox combo_force_3_type;
-	[Widget] Gtk.ComboBox combo_force_4_type;
-	[Widget] Gtk.ComboBox combo_force_impulse_type;
-	[Widget] Gtk.HBox hbox_force_1_at_ms;
-	[Widget] Gtk.HBox hbox_force_2_at_ms;
-	[Widget] Gtk.HBox hbox_force_3_at_ms;
-	[Widget] Gtk.HBox hbox_force_4_at_ms;
-	[Widget] Gtk.HBox hbox_force_1_at_percent;
-	[Widget] Gtk.HBox hbox_force_2_at_percent;
-	[Widget] Gtk.HBox hbox_force_3_at_percent;
-	[Widget] Gtk.HBox hbox_force_4_at_percent;
-	[Widget] Gtk.HBox hbox_force_impulse_until_percent;
-	[Widget] Gtk.HBox hbox_force_1_from_to;
-	[Widget] Gtk.HBox hbox_force_2_from_to;
-	[Widget] Gtk.HBox hbox_force_3_from_to;
-	[Widget] Gtk.HBox hbox_force_4_from_to;
-	[Widget] Gtk.HBox hbox_force_impulse_from_to;
-	[Widget] Gtk.SpinButton spinbutton_force_1_at_ms;
-	[Widget] Gtk.SpinButton spinbutton_force_2_at_ms;
-	[Widget] Gtk.SpinButton spinbutton_force_3_at_ms;
-	[Widget] Gtk.SpinButton spinbutton_force_4_at_ms;
-	[Widget] Gtk.SpinButton spinbutton_force_1_at_percent;
-	[Widget] Gtk.SpinButton spinbutton_force_2_at_percent;
-	[Widget] Gtk.SpinButton spinbutton_force_3_at_percent;
-	[Widget] Gtk.SpinButton spinbutton_force_4_at_percent;
-	[Widget] Gtk.SpinButton spinbutton_force_impulse_until_percent;
-	[Widget] Gtk.SpinButton spinbutton_force_1_from;
-	[Widget] Gtk.SpinButton spinbutton_force_2_from;
-	[Widget] Gtk.SpinButton spinbutton_force_3_from;
-	[Widget] Gtk.SpinButton spinbutton_force_4_from;
-	[Widget] Gtk.SpinButton spinbutton_force_impulse_from;
-	[Widget] Gtk.SpinButton spinbutton_force_1_to;
-	[Widget] Gtk.SpinButton spinbutton_force_2_to;
-	[Widget] Gtk.SpinButton spinbutton_force_3_to;
-	[Widget] Gtk.SpinButton spinbutton_force_4_to;
-	[Widget] Gtk.SpinButton spinbutton_force_impulse_to;
-
 	//multimedia tab
 	[Widget] Gtk.CheckButton checkbutton_volume;
 	[Widget] Gtk.Table table_gstreamer;
 	[Widget] Gtk.RadioButton radio_gstreamer_0_1;
 	[Widget] Gtk.RadioButton radio_gstreamer_1_0;
+	[Widget] Gtk.RadioButton radio_sound_systemsounds;
+	[Widget] Gtk.HBox hbox_not_recommended_when_not_on_windows;
 	[Widget] Gtk.Label label_test_sound_result;
 	[Widget] Gtk.Box hbox_combo_camera;
 	[Widget] Gtk.ComboBox combo_camera;
@@ -220,6 +159,8 @@ public class PreferencesWindow
 	[Widget] Gtk.Label label_advanced_feedback;
 	[Widget] Gtk.ToggleButton toggle_gc_collect_on_close;
 	[Widget] Gtk.ToggleButton toggle_never_close;
+	[Widget] Gtk.VBox vbox_version;
+	[Widget] Gtk.Label label_progVersion;
 
 
 	[Widget] Gtk.Button button_accept;
@@ -230,8 +171,6 @@ public class PreferencesWindow
 	static PreferencesWindow PreferencesWindowBox;
 	
 	private Preferences preferences; //stored to update SQL if anything changed
-	private List<ForceSensorRFD> rfdList; //stored to update SQL if anything changed
-	private ForceSensorImpulse impulse;
 	private Thread thread;
 
 	string databaseURL;
@@ -243,7 +182,6 @@ public class PreferencesWindow
 	const int RUNSPAGE = 3;
 	const int ENCODERCAPTUREPAGE = 4;
 	const int ENCODEROTHERPAGE = 5;
-	const int FORCEPAGE = 6;
 
 
 	PreferencesWindow () {
@@ -261,17 +199,24 @@ public class PreferencesWindow
 		FakeButtonImported = new Gtk.Button();
 		FakeButtonDebugModeStart = new Gtk.Button();
 	}
-	
-	static public PreferencesWindow Show (Preferences preferences, List <ForceSensorRFD> rfdList, ForceSensorImpulse impulse,
-			Constants.Menuitem_modes menu_mode, bool compujump)
+
+	static public PreferencesWindow Show (Preferences preferences,
+			Constants.Menuitem_modes menu_mode, bool compujump, string progVersion)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
 		if(compujump)
+		{
 			PreferencesWindowBox.check_appearance_person_win_hide.Sensitive = false;
 
+			//show version
+			PreferencesWindowBox.vbox_version.Visible = true;
+			PreferencesWindowBox.label_progVersion.Text = "<b>" + progVersion + "</b>";
+			PreferencesWindowBox.label_progVersion.UseMarkup = true;
+		}
+
 		if(menu_mode !=	Constants.Menuitem_modes.JUMPSSIMPLE && menu_mode != Constants.Menuitem_modes.JUMPSREACTIVE)
 			PreferencesWindowBox.notebook.GetNthPage(JUMPSPAGE).Hide();
 		if(menu_mode !=	Constants.Menuitem_modes.RUNSSIMPLE && menu_mode != Constants.Menuitem_modes.RUNSINTERVALLIC)
@@ -280,12 +225,8 @@ public class PreferencesWindow
 			PreferencesWindowBox.notebook.GetNthPage(ENCODERCAPTUREPAGE).Hide();
 			PreferencesWindowBox.notebook.GetNthPage(ENCODEROTHERPAGE).Hide();
 		}
-		if(menu_mode !=	Constants.Menuitem_modes.FORCESENSOR)
-			PreferencesWindowBox.notebook.GetNthPage(FORCEPAGE).Hide();
 
 		PreferencesWindowBox.preferences = preferences;
-		PreferencesWindowBox.rfdList = rfdList;
-		PreferencesWindowBox.impulse = impulse;
 
 		PreferencesWindowBox.createComboLanguage();
 
@@ -326,12 +267,21 @@ public class PreferencesWindow
 		else 
 			PreferencesWindowBox.checkbutton_volume.Active = false; 
 
-		PreferencesWindowBox.table_gstreamer.Visible = ! UtilAll.IsWindows();
+		if(UtilAll.IsWindows())
+		{
+			PreferencesWindowBox.table_gstreamer.Visible = false;
+			PreferencesWindowBox.hbox_not_recommended_when_not_on_windows.Visible = false;
+		} else {
+			PreferencesWindowBox.table_gstreamer.Visible = true;
+			PreferencesWindowBox.hbox_not_recommended_when_not_on_windows.Visible = true;
+		}
 
 		if(preferences.gstreamer == Preferences.GstreamerTypes.GST_0_1)
 			PreferencesWindowBox.radio_gstreamer_0_1.Active = true;
-		else
+		else if(preferences.gstreamer == Preferences.GstreamerTypes.GST_1_0)
 			PreferencesWindowBox.radio_gstreamer_1_0.Active = true;
+		else //(preferences.gstreamer == Preferences.GstreamerTypes.SYSTEMSOUNDS)
+			PreferencesWindowBox.radio_sound_systemsounds.Active = true;
 		PreferencesWindowBox.label_test_sound_result.Text = "";
 
 		PreferencesWindowBox.createComboCamera(UtilMultimedia.GetVideoDevices(), preferences.videoDeviceNum);
@@ -412,6 +362,7 @@ public class PreferencesWindow
 
 
 		//start of double contacts stuff ----
+
 		Pixbuf pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_simple.png");
 		PreferencesWindowBox.image_races_simple.Pixbuf = pixbuf;
@@ -437,23 +388,7 @@ public class PreferencesWindow
 			preferences.runDoubleContactsMS;
 		PreferencesWindowBox.spinbutton_runs_i_prevent_double_contact.Value = 
 			preferences.runIDoubleContactsMS;
-			
-		if(preferences.runDoubleContactsMode != Constants.DoubleContact.NONE) {
-			if(preferences.runDoubleContactsMode == Constants.DoubleContact.FIRST)
-				PreferencesWindowBox.radio_runs_prevent_double_contact_first.Active = true;
-			else if(preferences.runDoubleContactsMode == Constants.DoubleContact.AVERAGE)
-				PreferencesWindowBox.radio_runs_prevent_double_contact_average.Active = true;
-			else // Constants.DoubleContact.LAST  DEFAULT
-				PreferencesWindowBox.radio_runs_prevent_double_contact_last.Active = true;
-		}
-		if(preferences.runIDoubleContactsMode != Constants.DoubleContact.NONE) {
-			if(preferences.runIDoubleContactsMode == Constants.DoubleContact.FIRST)
-				PreferencesWindowBox.radio_runs_i_prevent_double_contact_first.Active = true;
-			else if(preferences.runIDoubleContactsMode == Constants.DoubleContact.LAST)
-				PreferencesWindowBox.radio_runs_i_prevent_double_contact_last.Active = true;
-			else //Constants.DoubleContact.AVERAGE  DEFAULT
-				PreferencesWindowBox.radio_runs_i_prevent_double_contact_average.Active = true;
-		}
+
 		//---- end of double contacts stuff		
 
 
@@ -466,9 +401,6 @@ public class PreferencesWindow
 		//encoder capture -->
 		PreferencesWindowBox.spin_encoder_capture_time.Value = preferences.encoderCaptureTime;
 		PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value = preferences.encoderCaptureInactivityEndTime;
-		
-		PreferencesWindowBox.createComboEncoderCaptureMainVariable(
-				Constants.GetEncoderVariablesCapture(preferences.encoderCaptureMainVariable));
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_gravity.png");
 		PreferencesWindowBox.image_encoder_gravitatory.Pixbuf = pixbuf;
@@ -530,9 +462,6 @@ public class PreferencesWindow
 
 		//done here and not in glade to be shown with the decimal point of user language	
 		PreferencesWindowBox.label_encoder_con.Text = (0.7).ToString();
-	
-		//force
-		PreferencesWindowBox.initForceSensor();
 
 		//language -->
 		if(preferences.language == "")
@@ -589,7 +518,7 @@ public class PreferencesWindow
 		new DialogMessage(
 				"Chronojump triggers",
 				Constants.MessageTypes.INFO,
-				Catalog.GetString("If active, repetitions will be cut from set using triggers.") + "\n" +
+				Catalog.GetString("If active, repetitions will be cut from set using triggers.") + " " +
 				Catalog.GetString("Trigger signal will be produced by a button connected to the Chronopic.") + "\n\n" +
 				Catalog.GetString("This will be only used on gravitatory mode, concentric contraction.") + "\n\n" +
 				Catalog.GetString("If \"Cut by triggers\" is inactive, repetitions will be cut automatically (default behaviour),") + " " +
@@ -609,18 +538,6 @@ public class PreferencesWindow
 	 * end of triggers stuff
 	 */
 
-	private void createComboEncoderCaptureMainVariable(string v) {
-		combo_main_variable = ComboBox.NewText ();
-		string [] values = Constants.EncoderVariablesCaptureList;
-		UtilGtk.ComboUpdate(combo_main_variable, values, "");
-		combo_main_variable.Active = UtilGtk.ComboMakeActive(combo_main_variable, v.ToString());
-		
-		hbox_combo_main_variable.PackStart(combo_main_variable, false, false, 0);
-		hbox_combo_main_variable.ShowAll();
-		combo_main_variable.Sensitive = true;
-	}
-
-	
 	private void createComboCamera(string [] devices, int current) {
 		combo_camera = ComboBox.NewText ();
 
@@ -655,297 +572,6 @@ public class PreferencesWindow
 	}
 
 
-	// ---- Force sensor stuff
-
-	private void initForceSensor ()
-	{
-		createForceCombos();
-		setRFDValues();
-		setImpulseValue();
-	}
-
-	private void check_force_visibilities()
-	{
-		hbox_force_1.Visible = (check_force_1.Active);
-		hbox_force_2.Visible = (check_force_2.Active);
-		hbox_force_3.Visible = (check_force_3.Active);
-		hbox_force_4.Visible = (check_force_4.Active);
-		hbox_force_impulse.Visible = (check_force_impulse.Active);
-	}
-
-	private void on_check_force_clicked (object o, EventArgs args)
-	{
-		check_force_visibilities();
-	}
-
-	private void createForceCombos ()
-	{
-		UtilGtk.ComboUpdate(combo_force_1_function, ForceSensorRFD.FunctionsArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_2_function, ForceSensorRFD.FunctionsArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_3_function, ForceSensorRFD.FunctionsArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_4_function, ForceSensorRFD.FunctionsArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_impulse_function, ForceSensorImpulse.FunctionsArray(true), "");
-
-		UtilGtk.ComboUpdate(combo_force_1_type, ForceSensorRFD.TypesArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_2_type, ForceSensorRFD.TypesArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_3_type, ForceSensorRFD.TypesArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_4_type, ForceSensorRFD.TypesArray(true), "");
-		UtilGtk.ComboUpdate(combo_force_impulse_type, ForceSensorImpulse.TypesArrayImpulse(true), "");
-	}
-
-	private void on_combo_force_type_changed (object o, EventArgs args)
-	{
-		Gtk.ComboBox combo = o as ComboBox;
-		if (o == null)
-			return;
-
-		if(combo == combo_force_1_type)
-			combo_force_visibility(
-					UtilGtk.ComboGetActive(combo_force_1_type),
-					hbox_force_1_at_ms,
-					hbox_force_1_at_percent,
-					hbox_force_1_from_to);
-		else if(combo == combo_force_2_type)
-			combo_force_visibility(
-					UtilGtk.ComboGetActive(combo_force_2_type),
-					hbox_force_2_at_ms,
-					hbox_force_2_at_percent,
-					hbox_force_2_from_to);
-		else if(combo == combo_force_3_type)
-			combo_force_visibility(
-					UtilGtk.ComboGetActive(combo_force_3_type),
-					hbox_force_3_at_ms,
-					hbox_force_3_at_percent,
-					hbox_force_3_from_to);
-		else if(combo == combo_force_4_type)
-			combo_force_visibility(
-					UtilGtk.ComboGetActive(combo_force_4_type),
-					hbox_force_4_at_ms,
-					hbox_force_4_at_percent,
-					hbox_force_4_from_to);
-		else if(combo == combo_force_impulse_type)
-			combo_force_impulse_visibility(
-					UtilGtk.ComboGetActive(combo_force_impulse_type),
-					hbox_force_impulse_until_percent,
-					hbox_force_impulse_from_to);
-	}
-
-	private void combo_force_visibility (string selected, Gtk.HBox at_ms, Gtk.HBox at_percent, Gtk.HBox from_to)
-	{
-		//valid for active == "" and active == "RFD max"
-		at_ms.Visible = false;
-		from_to.Visible = false;
-		at_percent.Visible = false;
-
-		if(selected == Catalog.GetString(ForceSensorRFD.Type_INSTANTANEOUS_name))
-		{
-			at_ms.Visible = true;
-		}
-		else if(selected == Catalog.GetString(ForceSensorRFD.Type_AVERAGE_name))
-		{
-			from_to.Visible = true;
-		}
-		else if(selected == Catalog.GetString(ForceSensorRFD.Type_PERCENT_F_MAX_name))
-		{
-			at_percent.Visible = true;
-		}
-	}
-	private void combo_force_impulse_visibility (string selected, Gtk.HBox until_percent, Gtk.HBox from_to)
-	{
-		until_percent.Visible = false;
-		from_to.Visible = false;
-
-		if(selected == Catalog.GetString(ForceSensorImpulse.Type_IMP_UNTIL_PERCENT_F_MAX_name))
-		{
-			until_percent.Visible = true;
-		}
-		else if(selected == Catalog.GetString(ForceSensorImpulse.Type_IMP_RANGE_name))
-		{
-			from_to.Visible = true;
-		}
-	}
-
-	private void setRFDValues ()
-	{
-		setRFDValue(rfdList[0], check_force_1, combo_force_1_function, combo_force_1_type,
-				hbox_force_1_at_ms, spinbutton_force_1_at_ms,
-				hbox_force_1_at_percent, spinbutton_force_1_at_percent,
-				hbox_force_1_from_to, spinbutton_force_1_from, spinbutton_force_1_to);
-
-		setRFDValue(rfdList[1], check_force_2, combo_force_2_function, combo_force_2_type,
-				hbox_force_2_at_ms, spinbutton_force_2_at_ms,
-				hbox_force_2_at_percent, spinbutton_force_2_at_percent,
-				hbox_force_2_from_to, spinbutton_force_2_from, spinbutton_force_2_to);
-
-		setRFDValue(rfdList[2], check_force_3, combo_force_3_function, combo_force_3_type,
-				hbox_force_3_at_ms, spinbutton_force_3_at_ms,
-				hbox_force_3_at_percent, spinbutton_force_3_at_percent,
-				hbox_force_3_from_to, spinbutton_force_3_from, spinbutton_force_3_to);
-
-		setRFDValue(rfdList[3], check_force_4, combo_force_4_function, combo_force_4_type,
-				hbox_force_4_at_ms, spinbutton_force_4_at_ms,
-				hbox_force_4_at_percent, spinbutton_force_4_at_percent,
-				hbox_force_4_from_to, spinbutton_force_4_from, spinbutton_force_4_to);
-	}
-
-	private void setRFDValue(ForceSensorRFD rfd, Gtk.CheckButton check, Gtk.ComboBox combo_force_function, Gtk.ComboBox combo_force_type,
-				Gtk.HBox hbox_force_at_ms, Gtk.SpinButton spinbutton_force_at_ms,
-				Gtk.HBox hbox_force_at_percent, Gtk.SpinButton spinbutton_force_at_percent,
-				Gtk.HBox hbox_force_from_to, Gtk.SpinButton spinbutton_force_from, Gtk.SpinButton spinbutton_force_to)
-	{
-		check.Active = rfd.active;
-
-		combo_force_function.Active = UtilGtk.ComboMakeActive(combo_force_function, rfd.FunctionPrint(true));
-		combo_force_type.Active = UtilGtk.ComboMakeActive(combo_force_type, rfd.TypePrint(true));
-
-		hbox_force_at_ms.Visible = false;
-		hbox_force_at_percent.Visible = false;
-		hbox_force_from_to.Visible = false;
-
-		if(rfd.type == ForceSensorRFD.Types.INSTANTANEOUS)
-		{
-			hbox_force_at_ms.Visible = true;
-			spinbutton_force_at_ms.Value = rfd.num1;
-		}
-		else if(rfd.type == ForceSensorRFD.Types.AVERAGE)
-		{
-			hbox_force_from_to.Visible = true;
-			spinbutton_force_from.Value = rfd.num1;
-			spinbutton_force_to.Value = rfd.num2;
-		}
-		else if(rfd.type == ForceSensorRFD.Types.PERCENT_F_MAX)
-		{
-			hbox_force_at_percent.Visible = true;
-			spinbutton_force_at_percent.Value = rfd.num1;
-		}
-	}
-
-	private List<ForceSensorRFD> getRFDValues()
-	{
-		List<ForceSensorRFD> l = new List<ForceSensorRFD>();
-		l.Add(getRFDValue("RFD1", check_force_1, combo_force_1_function, combo_force_1_type,
-				spinbutton_force_1_at_ms, spinbutton_force_1_at_percent,
-				spinbutton_force_1_from, spinbutton_force_1_to));
-		l.Add(getRFDValue("RFD2", check_force_2, combo_force_2_function, combo_force_2_type,
-				spinbutton_force_2_at_ms, spinbutton_force_2_at_percent,
-				spinbutton_force_2_from, spinbutton_force_2_to));
-		l.Add(getRFDValue("RFD3", check_force_3, combo_force_3_function, combo_force_3_type,
-				spinbutton_force_3_at_ms, spinbutton_force_3_at_percent,
-				spinbutton_force_3_from, spinbutton_force_3_to));
-		l.Add(getRFDValue("RFD4", check_force_4, combo_force_4_function, combo_force_4_type,
-				spinbutton_force_4_at_ms, spinbutton_force_4_at_percent,
-				spinbutton_force_4_from, spinbutton_force_4_to));
-		return l;
-	}
-	private ForceSensorRFD getRFDValue(string code, Gtk.CheckButton check, Gtk.ComboBox combo_force_function, Gtk.ComboBox combo_force_type,
-				Gtk.SpinButton spinbutton_force_at_ms, Gtk.SpinButton spinbutton_force_at_percent,
-				Gtk.SpinButton spinbutton_force_from, Gtk.SpinButton spinbutton_force_to)
-	{
-		bool active = check.Active;
-		int num1 = -1;
-		int num2 = -1;
-
-		ForceSensorRFD.Functions function;
-		if(UtilGtk.ComboGetActive(combo_force_function) == ForceSensorRFD.Function_RAW_name)
-			function = ForceSensorRFD.Functions.RAW;
-		else //(UtilGtk.ComboGetActive(combo_force_function) == ForceSensorRFD.Function_FITTED_name)
-			function = ForceSensorRFD.Functions.FITTED;
-
-		ForceSensorRFD.Types type;
-		string typeStr = UtilGtk.ComboGetActive(combo_force_type);
-		if(typeStr == Catalog.GetString(ForceSensorRFD.Type_INSTANTANEOUS_name))
-		{
-			num1 = Convert.ToInt32(spinbutton_force_at_ms.Value);
-			type = ForceSensorRFD.Types.INSTANTANEOUS;
-		}
-		else if(typeStr == Catalog.GetString(ForceSensorRFD.Type_AVERAGE_name))
-		{
-			num1 = Convert.ToInt32(spinbutton_force_from.Value);
-			num2 = Convert.ToInt32(spinbutton_force_to.Value);
-			type = ForceSensorRFD.Types.AVERAGE;
-		}
-		else if(typeStr == Catalog.GetString(ForceSensorRFD.Type_PERCENT_F_MAX_name))
-		{
-			num1 = Convert.ToInt32(spinbutton_force_at_percent.Value);
-			type = ForceSensorRFD.Types.PERCENT_F_MAX;
-		}
-		else // (typeStr == Catalog.GetString(ForceSensorRFD.Type_RFD_MAX_name))
-			type = ForceSensorRFD.Types.RFD_MAX;
-
-		return new ForceSensorRFD(code, active, function, type, num1, num2);
-	}
-
-	private void setImpulseValue ()
-	{
-		check_force_impulse.Active = impulse.active;
-
-		combo_force_impulse_function.Active = UtilGtk.ComboMakeActive(combo_force_impulse_function, impulse.FunctionPrint(true));
-		combo_force_impulse_type.Active = UtilGtk.ComboMakeActive(combo_force_impulse_type, impulse.TypePrint(true));
-
-		hbox_force_impulse_until_percent.Visible = false;
-		hbox_force_impulse_from_to.Visible = false;
-
-		if(impulse.type == ForceSensorImpulse.Types.IMP_UNTIL_PERCENT_F_MAX)
-		{
-			hbox_force_impulse_until_percent.Visible = true;
-			//num1 is 0
-			spinbutton_force_impulse_until_percent.Value = impulse.num2;
-		}
-		else if(impulse.type == ForceSensorImpulse.Types.IMP_RANGE)
-		{
-			hbox_force_impulse_from_to.Visible = true;
-			spinbutton_force_impulse_from.Value = impulse.num1;
-			spinbutton_force_impulse_to.Value = impulse.num2;
-		}
-	}
-	private ForceSensorImpulse getImpulseValue ()
-	{
-		bool active = check_force_impulse.Active;
-		int num1 = -1;
-		int num2 = -1;
-
-		ForceSensorImpulse.Functions function;
-		if(UtilGtk.ComboGetActive(combo_force_impulse_function) == ForceSensorImpulse.Function_RAW_name)
-			function = ForceSensorImpulse.Functions.RAW;
-		else //(UtilGtk.ComboGetActive(combo_force_impulse_function) == ForceSensorImpulse.Function_FITTED_name)
-			function = ForceSensorImpulse.Functions.FITTED;
-
-		ForceSensorImpulse.Types type;
-		string typeStr = UtilGtk.ComboGetActive(combo_force_impulse_type);
-
-		if(typeStr == Catalog.GetString(ForceSensorImpulse.Type_IMP_UNTIL_PERCENT_F_MAX_name))
-		{
-			num1 = 0;
-			num2 = Convert.ToInt32(spinbutton_force_impulse_until_percent.Value);
-			type = ForceSensorImpulse.Types.IMP_UNTIL_PERCENT_F_MAX;
-		}
-		else // if(typeStr == Catalog.GetString(ForceSensorImpulse.Type_IMP_RANGE_name))
-		{
-			num1 = Convert.ToInt32(spinbutton_force_impulse_from.Value);
-			num2 = Convert.ToInt32(spinbutton_force_impulse_to.Value);
-			type = ForceSensorImpulse.Types.IMP_RANGE;
-		}
-
-		return new ForceSensorImpulse(active, function, type, num1, num2);
-	}
-
-	private void on_button_force_rfd_default_clicked (object o, EventArgs args)
-	{
-		Sqlite.Open();
-
-		SqliteForceSensor.DeleteAll(true);
-		SqliteForceSensor.InsertDefaultValues(true);
-
-		rfdList = SqliteForceSensor.SelectAll(false);
-		impulse = SqliteForceSensor.SelectImpulse(false);
-
-		setRFDValues();
-		setImpulseValue();
-
-		Sqlite.Close();
-	}
-
-	// ---- end of Force sensor stuff
 
 	// ---- multimedia stuff
 
@@ -957,8 +583,10 @@ public class PreferencesWindow
 
 		if(radio_gstreamer_0_1.Active)
 			sc = Util.PlaySound(Constants.SoundTypes.GOOD, true, Preferences.GstreamerTypes.GST_0_1);
-		else // radio_gstreamer_1_0.Active
+		else if(radio_gstreamer_1_0.Active)
 			sc = Util.PlaySound(Constants.SoundTypes.GOOD, true, Preferences.GstreamerTypes.GST_1_0);
+		else
+			sc = Util.PlaySound(Constants.SoundTypes.GOOD, true, Preferences.GstreamerTypes.SYSTEMSOUNDS);
 
 		if(sc == Util.SoundCodes.OK)
 			label_test_sound_result.Text = Catalog.GetString("Sound working");
@@ -1603,21 +1231,9 @@ public class PreferencesWindow
 		}
 		else if(PreferencesWindowBox.checkbutton_runs_prevent_double_contact.Active) 
 		{
-			//1.2 mode has changed between FIRST, AVERAGE or LAST
-			if( PreferencesWindowBox.radio_runs_prevent_double_contact_first.Active &&
-					(preferences.runDoubleContactsMode != Constants.DoubleContact.FIRST) ) {
-				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.FIRST.ToString(), true);
-				preferences.runDoubleContactsMode = Constants.DoubleContact.FIRST;
-			}
-			else if( PreferencesWindowBox.radio_runs_prevent_double_contact_average.Active &&
-					(preferences.runDoubleContactsMode != Constants.DoubleContact.AVERAGE) ) {
-				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.AVERAGE.ToString(), true);
-				preferences.runDoubleContactsMode = Constants.DoubleContact.AVERAGE;
-			}
-			else if( PreferencesWindowBox.radio_runs_prevent_double_contact_last.Active &&
-					(preferences.runDoubleContactsMode != Constants.DoubleContact.LAST) ) {
-				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.LAST.ToString(), true);
-				preferences.runDoubleContactsMode = Constants.DoubleContact.LAST;
+			if( preferences.runDoubleContactsMode != Constants.DoubleContact.BIGGEST_TC ) {
+				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.BIGGEST_TC.ToString(), true);
+				preferences.runDoubleContactsMode = Constants.DoubleContact.BIGGEST_TC;
 			}
 
 			if(preferences.runDoubleContactsMS != (int) PreferencesWindowBox.spinbutton_runs_prevent_double_contact.Value) {
@@ -1638,21 +1254,9 @@ public class PreferencesWindow
 		}
 		else if(PreferencesWindowBox.checkbutton_runs_i_prevent_double_contact.Active) 
 		{
-			//2.2 mode has changed between FIRST, AVERAGE or LAST
-			if( PreferencesWindowBox.radio_runs_i_prevent_double_contact_first.Active &&
-					(preferences.runIDoubleContactsMode != Constants.DoubleContact.FIRST) ) {
-				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.FIRST.ToString(), true);
-				preferences.runIDoubleContactsMode = Constants.DoubleContact.FIRST;
-			}
-			else if( PreferencesWindowBox.radio_runs_i_prevent_double_contact_average.Active &&
-					(preferences.runIDoubleContactsMode != Constants.DoubleContact.AVERAGE) ) {
-				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.AVERAGE.ToString(), true);
-				preferences.runIDoubleContactsMode = Constants.DoubleContact.AVERAGE;
-			}
-			else if( PreferencesWindowBox.radio_runs_i_prevent_double_contact_last.Active &&
-					(preferences.runIDoubleContactsMode != Constants.DoubleContact.LAST) ) {
-				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.LAST.ToString(), true);
-				preferences.runIDoubleContactsMode = Constants.DoubleContact.LAST;
+			if( preferences.runIDoubleContactsMode != Constants.DoubleContact.BIGGEST_TC ) {
+				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.BIGGEST_TC.ToString(), true);
+				preferences.runIDoubleContactsMode = Constants.DoubleContact.BIGGEST_TC;
 			}
 			
 			if(preferences.runIDoubleContactsMS != (int) PreferencesWindowBox.spinbutton_runs_i_prevent_double_contact.Value) {
@@ -1676,14 +1280,7 @@ public class PreferencesWindow
 				preferences.encoderCaptureInactivityEndTime,
 				(int) PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value);
 
-	
-		Constants.EncoderVariablesCapture mainVariable = Constants.SetEncoderVariablesCapture(
-				UtilGtk.ComboGetActive(PreferencesWindowBox.combo_main_variable));
-		if( preferences.encoderCaptureMainVariable != mainVariable ) {
-			SqlitePreferences.Update("encoderCaptureMainVariable", mainVariable.ToString(), true);
-			preferences.encoderCaptureMainVariable = mainVariable;
-		}
-		
+
 		preferences.encoderCaptureMinHeightGravitatory = preferencesChange(
 				"encoderCaptureMinHeightGravitatory",
 				preferences.encoderCaptureMinHeightGravitatory,
@@ -1769,29 +1366,6 @@ public class PreferencesWindow
 		SqlitePreferences.Update("encoder1RMMethod", encoder1RMMethod.ToString(), true);
 		preferences.encoder1RMMethod = encoder1RMMethod;
 
-		//---- force sensor
-
-		List<ForceSensorRFD> newRFDList = getRFDValues();
-		int i = 0;
-		foreach(ForceSensorRFD rfd in newRFDList)
-		{
-			if(rfdList[i].Changed(rfd))
-			{
-				SqliteForceSensor.Update(true, rfd);
-				rfdList[i] = rfd;
-			}
-			i ++;
-		}
-
-		ForceSensorImpulse newImpulse = getImpulseValue();
-		if(newImpulse.Changed(impulse))
-		{
-			SqliteForceSensor.UpdateImpulse(true, newImpulse);
-			impulse = newImpulse;
-		}
-
-		// end of force sensor
-
 
 		//---- end of encoder other
 
@@ -1801,16 +1375,21 @@ public class PreferencesWindow
 			preferences.volumeOn = PreferencesWindowBox.checkbutton_volume.Active;
 		}
 
-		if( preferences.gstreamer == Preferences.GstreamerTypes.GST_0_1 && radio_gstreamer_1_0.Active)
+		if( preferences.gstreamer != Preferences.GstreamerTypes.GST_1_0 && radio_gstreamer_1_0.Active)
 		{
 			SqlitePreferences.Update(Preferences.GstreamerStr, Preferences.GstreamerTypes.GST_1_0.ToString(), true);
 			preferences.gstreamer = Preferences.GstreamerTypes.GST_1_0;
 		}
-		else if( preferences.gstreamer == Preferences.GstreamerTypes.GST_1_0 && radio_gstreamer_0_1.Active)
+		else if( preferences.gstreamer != Preferences.GstreamerTypes.GST_0_1 && radio_gstreamer_0_1.Active)
 		{
 			SqlitePreferences.Update(Preferences.GstreamerStr, Preferences.GstreamerTypes.GST_0_1.ToString(), true);
 			preferences.gstreamer = Preferences.GstreamerTypes.GST_0_1;
 		}
+		else if( preferences.gstreamer != Preferences.GstreamerTypes.SYSTEMSOUNDS && radio_sound_systemsounds.Active)
+		{
+			SqlitePreferences.Update(Preferences.GstreamerStr, Preferences.GstreamerTypes.SYSTEMSOUNDS.ToString(), true);
+			preferences.gstreamer = Preferences.GstreamerTypes.SYSTEMSOUNDS;
+		}
 
 		if( preferences.videoDeviceNum != UtilGtk.ComboGetActivePos(combo_camera) ) {
 			SqlitePreferences.Update("videoDevice", UtilGtk.ComboGetActivePos(combo_camera).ToString(), true);
@@ -1903,14 +1482,4 @@ public class PreferencesWindow
 	{
 		get { return preferences;  }
 	}
-
-	public List<ForceSensorRFD> GetRFDList
-	{
-		get { return rfdList;  }
-	}
-
-	public ForceSensorImpulse GetImpulse
-	{
-		get { return impulse;  }
-	}
 }
