@@ -47,7 +47,7 @@ public class Preferences
 
 	public Constants.DoubleContact runDoubleContactsMode; //default LAST
 	public int runDoubleContactsMS; //milliseconds
-	public Constants.DoubleContact runIDoubleContactsMode; //default AVERAGE
+	public Constants.DoubleContact runIDoubleContactsMode; //As 1.8.1 is NONE or BIGGEST_TC
 	public int runIDoubleContactsMS; //milliseconds
 
 	public int thresholdJumps;
@@ -115,9 +115,9 @@ public class Preferences
 	public double forceSensorCalibrationWeight;
 	public double forceSensorCalibrationFactor;
 				
-	public int encoderCaptureTimeIM = 120; //hardcoded 2 minutes.
+	public int encoderCaptureTimeIM = 180; //hardcoded 3 minutes.
 
-	public enum GstreamerTypes { GST_0_1, GST_1_0 };
+	public enum GstreamerTypes { GST_0_1, GST_1_0, SYSTEMSOUNDS }; //SYSTEMSOUNDS is the default sounds played on Windows
 	public GstreamerTypes gstreamer;
 	public static string GstreamerStr = "gstreamer"; //in order to ensure write correctly on SQL
 
